from .model.payment import *
from ..base import *
from ...utils import *


class PaymentClient(BaseClient):
    def __init__(self, config):
        super().__init__(config)
    

    def create_bankpay_order(self, request: CreateBankpayOrderRequest):
        """ 银行卡实时支付
   
        :type request: CreateBankpayOrderRequest
        :param request: the CreateBankpayOrderRequest request parameters class.
    
        :return: CreateBankpayOrderResponse
        """
        return self._post("/api/payment/v1/order-bankpay", request.request_id, Utils.copy_dict(request.__dict__))

    def create_alipay_order(self, request: CreateAlipayOrderRequest):
        """ 支付宝实时支付
   
        :type request: CreateAlipayOrderRequest
        :param request: the CreateAlipayOrderRequest request parameters class.
    
        :return: CreateAlipayOrderResponse
        """
        return self._post("/api/payment/v1/order-alipay", request.request_id, Utils.copy_dict(request.__dict__))

    def create_wxpay_order(self, request: CreateWxpayOrderRequest):
        """ 微信实时支付
   
        :type request: CreateWxpayOrderRequest
        :param request: the CreateWxpayOrderRequest request parameters class.
    
        :return: CreateWxpayOrderResponse
        """
        return self._post("/api/payment/v1/order-wxpay", request.request_id, Utils.copy_dict(request.__dict__))

    def get_order(self, request: GetOrderRequest):
        """ 查询单笔订单信息
   
        :type request: GetOrderRequest
        :param request: the GetOrderRequest request parameters class.
    
        :return: GetOrderResponse
        """
        return self._get("/api/payment/v1/query-order", request.request_id, Utils.copy_dict(request.__dict__))

    def get_dealer_v_a_recharge_account(self, request: GetDealerVARechargeAccountRequest):
        """ 查询平台企业汇款信息
   
        :type request: GetDealerVARechargeAccountRequest
        :param request: the GetDealerVARechargeAccountRequest request parameters class.
    
        :return: GetDealerVARechargeAccountResponse
        """
        return self._get("/api/payment/v1/va-account", request.request_id, Utils.copy_dict(request.__dict__))

    def list_account(self, request: ListAccountRequest):
        """ 查询平台企业余额
   
        :type request: ListAccountRequest
        :param request: the ListAccountRequest request parameters class.
    
        :return: ListAccountResponse
        """
        return self._get("/api/payment/v1/query-accounts", request.request_id, Utils.copy_dict(request.__dict__))

    def get_ele_receipt_file(self, request: GetEleReceiptFileRequest):
        """ 查询电子回单
   
        :type request: GetEleReceiptFileRequest
        :param request: the GetEleReceiptFileRequest request parameters class.
    
        :return: GetEleReceiptFileResponse
        """
        return self._get("/api/payment/v1/receipt/file", request.request_id, Utils.copy_dict(request.__dict__))

    def cancel_order(self, request: CancelOrderRequest):
        """ 取消待支付订单
   
        :type request: CancelOrderRequest
        :param request: the CancelOrderRequest request parameters class.
    
        :return: CancelOrderResponse
        """
        return self._post("/api/payment/v1/order/fail", request.request_id, Utils.copy_dict(request.__dict__))

    def create_batch_order(self, request: CreateBatchOrderRequest):
        """ 批次下单
   
        :type request: CreateBatchOrderRequest
        :param request: the CreateBatchOrderRequest request parameters class.
    
        :return: CreateBatchOrderResponse
        """
        return self._post("/api/payment/v1/order-batch", request.request_id, Utils.copy_dict(request.__dict__))

    def confirm_batch_order(self, request: ConfirmBatchOrderRequest):
        """ 批次确认
   
        :type request: ConfirmBatchOrderRequest
        :param request: the ConfirmBatchOrderRequest request parameters class.
    
        :return: ConfirmBatchOrderResponse
        """
        return self._post("/api/payment/v1/confirm-batch", request.request_id, Utils.copy_dict(request.__dict__))
     


from ...base import BaseRequest
 

class H5GetStartUrlRequest(BaseRequest):
    """
    
    :type dealer_id: string
    :param dealer_id: 平台企业 ID
    
    :type broker_id: string
    :param broker_id: 综合服务主体 ID
    
    :type dealer_user_id: string
    :param dealer_user_id: 平台企业端的用户 ID
    
    :type client_type: int
    :param client_type: 客户端类型
    
    :type notify_url: string
    :param notify_url: 异步通知 URL
    
    :type color: string
    :param color: H5 页面主题颜色
    
    :type return_url: string
    :param return_url: 跳转 URL
    
    :type custom_title: int
    :param custom_title: H5 页面 Title
    """
    def __init__(self, dealer_id=None, broker_id=None, dealer_user_id=None, client_type=None, notify_url=None, color=None, return_url=None, custom_title=None):
        super().__init__() 
        self.dealer_id = dealer_id 
        self.broker_id = broker_id 
        self.dealer_user_id = dealer_user_id 
        self.client_type = client_type 
        self.notify_url = notify_url 
        self.color = color 
        self.return_url = return_url 
        self.custom_title = custom_title

    def get_dealer_id(self):
        """ Get 平台企业 ID

        :return: string, dealer_id
        """
        return self.dealer_id

    def set_dealer_id(self, dealer_id):
        """ Set 平台企业 ID

        :type dealer_id: string
        :param dealer_id: 平台企业 ID
        """
        self.dealer_id = dealer_id

    def get_broker_id(self):
        """ Get 综合服务主体 ID

        :return: string, broker_id
        """
        return self.broker_id

    def set_broker_id(self, broker_id):
        """ Set 综合服务主体 ID

        :type broker_id: string
        :param broker_id: 综合服务主体 ID
        """
        self.broker_id = broker_id

    def get_dealer_user_id(self):
        """ Get 平台企业端的用户 ID

        :return: string, dealer_user_id
        """
        return self.dealer_user_id

    def set_dealer_user_id(self, dealer_user_id):
        """ Set 平台企业端的用户 ID

        :type dealer_user_id: string
        :param dealer_user_id: 平台企业端的用户 ID
        """
        self.dealer_user_id = dealer_user_id

    def get_client_type(self):
        """ Get 客户端类型

        :return: int, client_type
        """
        return self.client_type

    def set_client_type(self, client_type):
        """ Set 客户端类型

        :type client_type: int
        :param client_type: 客户端类型
        """
        self.client_type = client_type

    def get_notify_url(self):
        """ Get 异步通知 URL

        :return: string, notify_url
        """
        return self.notify_url

    def set_notify_url(self, notify_url):
        """ Set 异步通知 URL

        :type notify_url: string
        :param notify_url: 异步通知 URL
        """
        self.notify_url = notify_url

    def get_color(self):
        """ Get H5 页面主题颜色

        :return: string, color
        """
        return self.color

    def set_color(self, color):
        """ Set H5 页面主题颜色

        :type color: string
        :param color: H5 页面主题颜色
        """
        self.color = color

    def get_return_url(self):
        """ Get 跳转 URL

        :return: string, return_url
        """
        return self.return_url

    def set_return_url(self, return_url):
        """ Set 跳转 URL

        :type return_url: string
        :param return_url: 跳转 URL
        """
        self.return_url = return_url

    def get_custom_title(self):
        """ Get H5 页面 Title

        :return: int, custom_title
        """
        return self.custom_title

    def set_custom_title(self, custom_title):
        """ Set H5 页面 Title

        :type custom_title: int
        :param custom_title: H5 页面 Title
        """
        self.custom_title = custom_title 

class H5GetStartUrlResponse(BaseRequest):
    """
    
    :type h5_url: string
    :param h5_url: 跳转 URL
    """
    def __init__(self, h5_url=None):
        super().__init__() 
        self.h5_url = h5_url

    def get_h5_url(self):
        """ Get 跳转 URL

        :return: string, h5_url
        """
        return self.h5_url

    def set_h5_url(self, h5_url):
        """ Set 跳转 URL

        :type h5_url: string
        :param h5_url: 跳转 URL
        """
        self.h5_url = h5_url 

class H5EcoCityAicStatusRequest(BaseRequest):
    """
    
    :type dealer_id: string
    :param dealer_id: 平台企业 ID
    
    :type broker_id: string
    :param broker_id: 综合服务主体 ID
    
    :type dealer_user_id: string
    :param dealer_user_id: 平台企业端的用户 ID
    
    :type id_card: string
    :param id_card: 身份证号码
    
    :type real_name: string
    :param real_name: 姓名
    
    :type open_id: string
    :param open_id: 用户唯一标识
    """
    def __init__(self, dealer_id=None, broker_id=None, dealer_user_id=None, id_card=None, real_name=None, open_id=None):
        super().__init__() 
        self.dealer_id = dealer_id 
        self.broker_id = broker_id 
        self.dealer_user_id = dealer_user_id 
        self.id_card = id_card 
        self.real_name = real_name 
        self.open_id = open_id

    def get_dealer_id(self):
        """ Get 平台企业 ID

        :return: string, dealer_id
        """
        return self.dealer_id

    def set_dealer_id(self, dealer_id):
        """ Set 平台企业 ID

        :type dealer_id: string
        :param dealer_id: 平台企业 ID
        """
        self.dealer_id = dealer_id

    def get_broker_id(self):
        """ Get 综合服务主体 ID

        :return: string, broker_id
        """
        return self.broker_id

    def set_broker_id(self, broker_id):
        """ Set 综合服务主体 ID

        :type broker_id: string
        :param broker_id: 综合服务主体 ID
        """
        self.broker_id = broker_id

    def get_dealer_user_id(self):
        """ Get 平台企业端的用户 ID

        :return: string, dealer_user_id
        """
        return self.dealer_user_id

    def set_dealer_user_id(self, dealer_user_id):
        """ Set 平台企业端的用户 ID

        :type dealer_user_id: string
        :param dealer_user_id: 平台企业端的用户 ID
        """
        self.dealer_user_id = dealer_user_id

    def get_id_card(self):
        """ Get 身份证号码

        :return: string, id_card
        """
        return self.id_card

    def set_id_card(self, id_card):
        """ Set 身份证号码

        :type id_card: string
        :param id_card: 身份证号码
        """
        self.id_card = id_card

    def get_real_name(self):
        """ Get 姓名

        :return: string, real_name
        """
        return self.real_name

    def set_real_name(self, real_name):
        """ Set 姓名

        :type real_name: string
        :param real_name: 姓名
        """
        self.real_name = real_name

    def get_open_id(self):
        """ Get 用户唯一标识

        :return: string, open_id
        """
        return self.open_id

    def set_open_id(self, open_id):
        """ Set 用户唯一标识

        :type open_id: string
        :param open_id: 用户唯一标识
        """
        self.open_id = open_id 

class H5EcoCityAicStatusResponse(BaseRequest):
    """
    
    :type status: int
    :param status: 用户签约状态
    
    :type status_message: string
    :param status_message: 注册状态描述
    
    :type status_detail: int
    :param status_detail: 注册详情状态码
    
    :type status_detail_message: string
    :param status_detail_message: 注册详情状态码描述
    
    :type applyed_at: string
    :param applyed_at: 注册发起时间
    
    :type registed_at: string
    :param registed_at: 注册完成时间
    
    :type uscc: string
    :param uscc: 统一社会信用代码
    
    :type id_card: string
    :param id_card: 身份证号码
    
    :type real_name: string
    :param real_name: 姓名
    """
    def __init__(self, status=None, status_message=None, status_detail=None, status_detail_message=None, applyed_at=None, registed_at=None, uscc=None, id_card=None, real_name=None):
        super().__init__() 
        self.status = status 
        self.status_message = status_message 
        self.status_detail = status_detail 
        self.status_detail_message = status_detail_message 
        self.applyed_at = applyed_at 
        self.registed_at = registed_at 
        self.uscc = uscc 
        self.id_card = id_card 
        self.real_name = real_name

    def get_status(self):
        """ Get 用户签约状态

        :return: int, status
        """
        return self.status

    def set_status(self, status):
        """ Set 用户签约状态

        :type status: int
        :param status: 用户签约状态
        """
        self.status = status

    def get_status_message(self):
        """ Get 注册状态描述

        :return: string, status_message
        """
        return self.status_message

    def set_status_message(self, status_message):
        """ Set 注册状态描述

        :type status_message: string
        :param status_message: 注册状态描述
        """
        self.status_message = status_message

    def get_status_detail(self):
        """ Get 注册详情状态码

        :return: int, status_detail
        """
        return self.status_detail

    def set_status_detail(self, status_detail):
        """ Set 注册详情状态码

        :type status_detail: int
        :param status_detail: 注册详情状态码
        """
        self.status_detail = status_detail

    def get_status_detail_message(self):
        """ Get 注册详情状态码描述

        :return: string, status_detail_message
        """
        return self.status_detail_message

    def set_status_detail_message(self, status_detail_message):
        """ Set 注册详情状态码描述

        :type status_detail_message: string
        :param status_detail_message: 注册详情状态码描述
        """
        self.status_detail_message = status_detail_message

    def get_applyed_at(self):
        """ Get 注册发起时间

        :return: string, applyed_at
        """
        return self.applyed_at

    def set_applyed_at(self, applyed_at):
        """ Set 注册发起时间

        :type applyed_at: string
        :param applyed_at: 注册发起时间
        """
        self.applyed_at = applyed_at

    def get_registed_at(self):
        """ Get 注册完成时间

        :return: string, registed_at
        """
        return self.registed_at

    def set_registed_at(self, registed_at):
        """ Set 注册完成时间

        :type registed_at: string
        :param registed_at: 注册完成时间
        """
        self.registed_at = registed_at

    def get_uscc(self):
        """ Get 统一社会信用代码

        :return: string, uscc
        """
        return self.uscc

    def set_uscc(self, uscc):
        """ Set 统一社会信用代码

        :type uscc: string
        :param uscc: 统一社会信用代码
        """
        self.uscc = uscc

    def get_id_card(self):
        """ Get 身份证号码

        :return: string, id_card
        """
        return self.id_card

    def set_id_card(self, id_card):
        """ Set 身份证号码

        :type id_card: string
        :param id_card: 身份证号码
        """
        self.id_card = id_card

    def get_real_name(self):
        """ Get 姓名

        :return: string, real_name
        """
        return self.real_name

    def set_real_name(self, real_name):
        """ Set 姓名

        :type real_name: string
        :param real_name: 姓名
        """
        self.real_name = real_name 

class NotifyH5EcoCityAicRequest(BaseRequest):
    """
    
    :type open_id: string
    :param open_id: 用户唯一标识
    
    :type dealer_user_id: string
    :param dealer_user_id: 平台企业端的用户 ID
    
    :type submit_at: string
    :param submit_at: 注册/注销提交时间
    
    :type registed_at: string
    :param registed_at: 注册/注销完成时间
    
    :type status: int
    :param status: 用户签约状态
    
    :type status_message: string
    :param status_message: 注册状态描述
    
    :type status_detail: int
    :param status_detail: 注册详情状态码
    
    :type status_detail_message: string
    :param status_detail_message: 注册详情状态码描述
    
    :type dealer_id: string
    :param dealer_id: 平台企业 ID
    
    :type broker_id: string
    :param broker_id: 综合服务主体 ID
    
    :type uscc: string
    :param uscc: 统一社会信用代码
    
    :type id_card: string
    :param id_card: 身份证号码
    
    :type real_name: string
    :param real_name: 姓名
    
    :type type: int
    :param type: 回调类型
    """
    def __init__(self, open_id=None, dealer_user_id=None, submit_at=None, registed_at=None, status=None, status_message=None, status_detail=None, status_detail_message=None, dealer_id=None, broker_id=None, uscc=None, id_card=None, real_name=None, type=None):
        super().__init__() 
        self.open_id = open_id 
        self.dealer_user_id = dealer_user_id 
        self.submit_at = submit_at 
        self.registed_at = registed_at 
        self.status = status 
        self.status_message = status_message 
        self.status_detail = status_detail 
        self.status_detail_message = status_detail_message 
        self.dealer_id = dealer_id 
        self.broker_id = broker_id 
        self.uscc = uscc 
        self.id_card = id_card 
        self.real_name = real_name 
        self.type = type

    def get_open_id(self):
        """ Get 用户唯一标识

        :return: string, open_id
        """
        return self.open_id

    def set_open_id(self, open_id):
        """ Set 用户唯一标识

        :type open_id: string
        :param open_id: 用户唯一标识
        """
        self.open_id = open_id

    def get_dealer_user_id(self):
        """ Get 平台企业端的用户 ID

        :return: string, dealer_user_id
        """
        return self.dealer_user_id

    def set_dealer_user_id(self, dealer_user_id):
        """ Set 平台企业端的用户 ID

        :type dealer_user_id: string
        :param dealer_user_id: 平台企业端的用户 ID
        """
        self.dealer_user_id = dealer_user_id

    def get_submit_at(self):
        """ Get 注册/注销提交时间

        :return: string, submit_at
        """
        return self.submit_at

    def set_submit_at(self, submit_at):
        """ Set 注册/注销提交时间

        :type submit_at: string
        :param submit_at: 注册/注销提交时间
        """
        self.submit_at = submit_at

    def get_registed_at(self):
        """ Get 注册/注销完成时间

        :return: string, registed_at
        """
        return self.registed_at

    def set_registed_at(self, registed_at):
        """ Set 注册/注销完成时间

        :type registed_at: string
        :param registed_at: 注册/注销完成时间
        """
        self.registed_at = registed_at

    def get_status(self):
        """ Get 用户签约状态

        :return: int, status
        """
        return self.status

    def set_status(self, status):
        """ Set 用户签约状态

        :type status: int
        :param status: 用户签约状态
        """
        self.status = status

    def get_status_message(self):
        """ Get 注册状态描述

        :return: string, status_message
        """
        return self.status_message

    def set_status_message(self, status_message):
        """ Set 注册状态描述

        :type status_message: string
        :param status_message: 注册状态描述
        """
        self.status_message = status_message

    def get_status_detail(self):
        """ Get 注册详情状态码

        :return: int, status_detail
        """
        return self.status_detail

    def set_status_detail(self, status_detail):
        """ Set 注册详情状态码

        :type status_detail: int
        :param status_detail: 注册详情状态码
        """
        self.status_detail = status_detail

    def get_status_detail_message(self):
        """ Get 注册详情状态码描述

        :return: string, status_detail_message
        """
        return self.status_detail_message

    def set_status_detail_message(self, status_detail_message):
        """ Set 注册详情状态码描述

        :type status_detail_message: string
        :param status_detail_message: 注册详情状态码描述
        """
        self.status_detail_message = status_detail_message

    def get_dealer_id(self):
        """ Get 平台企业 ID

        :return: string, dealer_id
        """
        return self.dealer_id

    def set_dealer_id(self, dealer_id):
        """ Set 平台企业 ID

        :type dealer_id: string
        :param dealer_id: 平台企业 ID
        """
        self.dealer_id = dealer_id

    def get_broker_id(self):
        """ Get 综合服务主体 ID

        :return: string, broker_id
        """
        return self.broker_id

    def set_broker_id(self, broker_id):
        """ Set 综合服务主体 ID

        :type broker_id: string
        :param broker_id: 综合服务主体 ID
        """
        self.broker_id = broker_id

    def get_uscc(self):
        """ Get 统一社会信用代码

        :return: string, uscc
        """
        return self.uscc

    def set_uscc(self, uscc):
        """ Set 统一社会信用代码

        :type uscc: string
        :param uscc: 统一社会信用代码
        """
        self.uscc = uscc

    def get_id_card(self):
        """ Get 身份证号码

        :return: string, id_card
        """
        return self.id_card

    def set_id_card(self, id_card):
        """ Set 身份证号码

        :type id_card: string
        :param id_card: 身份证号码
        """
        self.id_card = id_card

    def get_real_name(self):
        """ Get 姓名

        :return: string, real_name
        """
        return self.real_name

    def set_real_name(self, real_name):
        """ Set 姓名

        :type real_name: string
        :param real_name: 姓名
        """
        self.real_name = real_name

    def get_type(self):
        """ Get 回调类型

        :return: int, type
        """
        return self.type

    def set_type(self, type):
        """ Set 回调类型

        :type type: int
        :param type: 回调类型
        """
        self.type = type


from ...base import BaseRequest
 

class GetInvoiceStatRequest(BaseRequest):
    """
    
    :type broker_id: string
    :param broker_id: 综合服务主体 ID
    
    :type dealer_id: string
    :param dealer_id: 平台企业 ID
    
    :type year: int
    :param year: 查询年份
    """
    def __init__(self, broker_id=None, dealer_id=None, year=None):
        super().__init__() 
        self.broker_id = broker_id 
        self.dealer_id = dealer_id 
        self.year = year

    def get_broker_id(self):
        """ Get 综合服务主体 ID

        :return: string, broker_id
        """
        return self.broker_id

    def set_broker_id(self, broker_id):
        """ Set 综合服务主体 ID

        :type broker_id: string
        :param broker_id: 综合服务主体 ID
        """
        self.broker_id = broker_id

    def get_dealer_id(self):
        """ Get 平台企业 ID

        :return: string, dealer_id
        """
        return self.dealer_id

    def set_dealer_id(self, dealer_id):
        """ Set 平台企业 ID

        :type dealer_id: string
        :param dealer_id: 平台企业 ID
        """
        self.dealer_id = dealer_id

    def get_year(self):
        """ Get 查询年份

        :return: int, year
        """
        return self.year

    def set_year(self, year):
        """ Set 查询年份

        :type year: int
        :param year: 查询年份
        """
        self.year = year 

class GetInvoiceStatResponse(BaseRequest):
    """
    
    :type dealer_id: string
    :param dealer_id: 平台企业 ID
    
    :type broker_id: string
    :param broker_id: 综合服务主体 ID
    
    :type invoiced: string
    :param invoiced: 已开发票金额
    
    :type invoicing: string
    :param invoicing: 开票中发票金额
    
    :type not_invoiced: string
    :param not_invoiced: 待开发票金额
    """
    def __init__(self, dealer_id=None, broker_id=None, invoiced=None, invoicing=None, not_invoiced=None):
        super().__init__() 
        self.dealer_id = dealer_id 
        self.broker_id = broker_id 
        self.invoiced = invoiced 
        self.invoicing = invoicing 
        self.not_invoiced = not_invoiced

    def get_dealer_id(self):
        """ Get 平台企业 ID

        :return: string, dealer_id
        """
        return self.dealer_id

    def set_dealer_id(self, dealer_id):
        """ Set 平台企业 ID

        :type dealer_id: string
        :param dealer_id: 平台企业 ID
        """
        self.dealer_id = dealer_id

    def get_broker_id(self):
        """ Get 综合服务主体 ID

        :return: string, broker_id
        """
        return self.broker_id

    def set_broker_id(self, broker_id):
        """ Set 综合服务主体 ID

        :type broker_id: string
        :param broker_id: 综合服务主体 ID
        """
        self.broker_id = broker_id

    def get_invoiced(self):
        """ Get 已开发票金额

        :return: string, invoiced
        """
        return self.invoiced

    def set_invoiced(self, invoiced):
        """ Set 已开发票金额

        :type invoiced: string
        :param invoiced: 已开发票金额
        """
        self.invoiced = invoiced

    def get_invoicing(self):
        """ Get 开票中发票金额

        :return: string, invoicing
        """
        return self.invoicing

    def set_invoicing(self, invoicing):
        """ Set 开票中发票金额

        :type invoicing: string
        :param invoicing: 开票中发票金额
        """
        self.invoicing = invoicing

    def get_not_invoiced(self):
        """ Get 待开发票金额

        :return: string, not_invoiced
        """
        return self.not_invoiced

    def set_not_invoiced(self, not_invoiced):
        """ Set 待开发票金额

        :type not_invoiced: string
        :param not_invoiced: 待开发票金额
        """
        self.not_invoiced = not_invoiced 

class GetInvoiceAmountRequest(BaseRequest):
    """
    
    :type broker_id: string
    :param broker_id: 综合服务主体 ID
    
    :type dealer_id: string
    :param dealer_id: 平台企业 ID
    """
    def __init__(self, broker_id=None, dealer_id=None):
        super().__init__() 
        self.broker_id = broker_id 
        self.dealer_id = dealer_id

    def get_broker_id(self):
        """ Get 综合服务主体 ID

        :return: string, broker_id
        """
        return self.broker_id

    def set_broker_id(self, broker_id):
        """ Set 综合服务主体 ID

        :type broker_id: string
        :param broker_id: 综合服务主体 ID
        """
        self.broker_id = broker_id

    def get_dealer_id(self):
        """ Get 平台企业 ID

        :return: string, dealer_id
        """
        return self.dealer_id

    def set_dealer_id(self, dealer_id):
        """ Set 平台企业 ID

        :type dealer_id: string
        :param dealer_id: 平台企业 ID
        """
        self.dealer_id = dealer_id 

class GetInvoiceAmountResponse(BaseRequest):
    """
    
    :type amount: string
    :param amount: 可开票额度
    
    :type bank_name_account: list
    :param bank_name_account: 系统支持的开户行及账号
    
    :type goods_services_name: list
    :param goods_services_name: 系统支持的货物或应税劳务、服务名称
    """
    def __init__(self, amount=None, bank_name_account=None, goods_services_name=None):
        super().__init__() 
        self.amount = amount 
        self.bank_name_account = bank_name_account 
        self.goods_services_name = goods_services_name

    def get_amount(self):
        """ Get 可开票额度

        :return: string, amount
        """
        return self.amount

    def set_amount(self, amount):
        """ Set 可开票额度

        :type amount: string
        :param amount: 可开票额度
        """
        self.amount = amount

    def get_bank_name_account(self):
        """ Get 系统支持的开户行及账号

        :return: list, bank_name_account
        """
        return self.bank_name_account

    def set_bank_name_account(self, bank_name_account):
        """ Set 系统支持的开户行及账号

        :type bank_name_account: list
        :param bank_name_account: 系统支持的开户行及账号
        """
        self.bank_name_account = bank_name_account

    def get_goods_services_name(self):
        """ Get 系统支持的货物或应税劳务、服务名称

        :return: list, goods_services_name
        """
        return self.goods_services_name

    def set_goods_services_name(self, goods_services_name):
        """ Set 系统支持的货物或应税劳务、服务名称

        :type goods_services_name: list
        :param goods_services_name: 系统支持的货物或应税劳务、服务名称
        """
        self.goods_services_name = goods_services_name 

class ApplyInvoiceRequest(BaseRequest):
    """
    
    :type invoice_apply_id: string
    :param invoice_apply_id: 发票申请编号
    
    :type broker_id: string
    :param broker_id: 综合服务主体 ID
    
    :type dealer_id: string
    :param dealer_id: 平台企业 ID
    
    :type amount: string
    :param amount: 申请开票金额
    
    :type invoice_type: string
    :param invoice_type: 发票类型
    
    :type bank_name_account: string
    :param bank_name_account: 开户行及账号
    
    :type goods_services_name: string
    :param goods_services_name: 货物或应税劳务、服务名称
    
    :type remark: string
    :param remark: 发票备注
    """
    def __init__(self, invoice_apply_id=None, broker_id=None, dealer_id=None, amount=None, invoice_type=None, bank_name_account=None, goods_services_name=None, remark=None):
        super().__init__() 
        self.invoice_apply_id = invoice_apply_id 
        self.broker_id = broker_id 
        self.dealer_id = dealer_id 
        self.amount = amount 
        self.invoice_type = invoice_type 
        self.bank_name_account = bank_name_account 
        self.goods_services_name = goods_services_name 
        self.remark = remark

    def get_invoice_apply_id(self):
        """ Get 发票申请编号

        :return: string, invoice_apply_id
        """
        return self.invoice_apply_id

    def set_invoice_apply_id(self, invoice_apply_id):
        """ Set 发票申请编号

        :type invoice_apply_id: string
        :param invoice_apply_id: 发票申请编号
        """
        self.invoice_apply_id = invoice_apply_id

    def get_broker_id(self):
        """ Get 综合服务主体 ID

        :return: string, broker_id
        """
        return self.broker_id

    def set_broker_id(self, broker_id):
        """ Set 综合服务主体 ID

        :type broker_id: string
        :param broker_id: 综合服务主体 ID
        """
        self.broker_id = broker_id

    def get_dealer_id(self):
        """ Get 平台企业 ID

        :return: string, dealer_id
        """
        return self.dealer_id

    def set_dealer_id(self, dealer_id):
        """ Set 平台企业 ID

        :type dealer_id: string
        :param dealer_id: 平台企业 ID
        """
        self.dealer_id = dealer_id

    def get_amount(self):
        """ Get 申请开票金额

        :return: string, amount
        """
        return self.amount

    def set_amount(self, amount):
        """ Set 申请开票金额

        :type amount: string
        :param amount: 申请开票金额
        """
        self.amount = amount

    def get_invoice_type(self):
        """ Get 发票类型

        :return: string, invoice_type
        """
        return self.invoice_type

    def set_invoice_type(self, invoice_type):
        """ Set 发票类型

        :type invoice_type: string
        :param invoice_type: 发票类型
        """
        self.invoice_type = invoice_type

    def get_bank_name_account(self):
        """ Get 开户行及账号

        :return: string, bank_name_account
        """
        return self.bank_name_account

    def set_bank_name_account(self, bank_name_account):
        """ Set 开户行及账号

        :type bank_name_account: string
        :param bank_name_account: 开户行及账号
        """
        self.bank_name_account = bank_name_account

    def get_goods_services_name(self):
        """ Get 货物或应税劳务、服务名称

        :return: string, goods_services_name
        """
        return self.goods_services_name

    def set_goods_services_name(self, goods_services_name):
        """ Set 货物或应税劳务、服务名称

        :type goods_services_name: string
        :param goods_services_name: 货物或应税劳务、服务名称
        """
        self.goods_services_name = goods_services_name

    def get_remark(self):
        """ Get 发票备注

        :return: string, remark
        """
        return self.remark

    def set_remark(self, remark):
        """ Set 发票备注

        :type remark: string
        :param remark: 发票备注
        """
        self.remark = remark 

class ApplyInvoiceResponse(BaseRequest):
    """
    
    :type application_id: string
    :param application_id: 发票申请单 ID
    
    :type count: int
    :param count: 发票张数
    """
    def __init__(self, application_id=None, count=None):
        super().__init__() 
        self.application_id = application_id 
        self.count = count

    def get_application_id(self):
        """ Get 发票申请单 ID

        :return: string, application_id
        """
        return self.application_id

    def set_application_id(self, application_id):
        """ Set 发票申请单 ID

        :type application_id: string
        :param application_id: 发票申请单 ID
        """
        self.application_id = application_id

    def get_count(self):
        """ Get 发票张数

        :return: int, count
        """
        return self.count

    def set_count(self, count):
        """ Set 发票张数

        :type count: int
        :param count: 发票张数
        """
        self.count = count 

class GetInvoiceStatusRequest(BaseRequest):
    """
    
    :type invoice_apply_id: string
    :param invoice_apply_id: 发票申请编号
    
    :type application_id: string
    :param application_id: 发票申请单 ID
    """
    def __init__(self, invoice_apply_id=None, application_id=None):
        super().__init__() 
        self.invoice_apply_id = invoice_apply_id 
        self.application_id = application_id

    def get_invoice_apply_id(self):
        """ Get 发票申请编号

        :return: string, invoice_apply_id
        """
        return self.invoice_apply_id

    def set_invoice_apply_id(self, invoice_apply_id):
        """ Set 发票申请编号

        :type invoice_apply_id: string
        :param invoice_apply_id: 发票申请编号
        """
        self.invoice_apply_id = invoice_apply_id

    def get_application_id(self):
        """ Get 发票申请单 ID

        :return: string, application_id
        """
        return self.application_id

    def set_application_id(self, application_id):
        """ Set 发票申请单 ID

        :type application_id: string
        :param application_id: 发票申请单 ID
        """
        self.application_id = application_id 

class GetInvoiceStatusResponse(BaseRequest):
    """
    
    :type status: string
    :param status: 申请结果
    
    :type count: int
    :param count: 发票张数
    
    :type price_tax_amount: string
    :param price_tax_amount: 价税合计
    
    :type price_amount: string
    :param price_amount: 不含税金额
    
    :type tax_amount: string
    :param tax_amount: 税额
    
    :type invoice_type: string
    :param invoice_type: 发票类型
    
    :type customer_name: string
    :param customer_name: 购方名称
    
    :type customer_tax_num: string
    :param customer_tax_num: 纳税人识别号
    
    :type customer_address_tel: string
    :param customer_address_tel: 购方地址、电话
    
    :type bank_name_account: string
    :param bank_name_account: 开户行及账号
    
    :type goods_services_name: string
    :param goods_services_name: 货物或应税劳务、服务名称
    
    :type remark: string
    :param remark: 发票备注
    
    :type post_type: string
    :param post_type: 邮寄类型
    
    :type waybill_number: list
    :param waybill_number: 快递单号
    """
    def __init__(self, status=None, count=None, price_tax_amount=None, price_amount=None, tax_amount=None, invoice_type=None, customer_name=None, customer_tax_num=None, customer_address_tel=None, bank_name_account=None, goods_services_name=None, remark=None, post_type=None, waybill_number=None):
        super().__init__() 
        self.status = status 
        self.count = count 
        self.price_tax_amount = price_tax_amount 
        self.price_amount = price_amount 
        self.tax_amount = tax_amount 
        self.invoice_type = invoice_type 
        self.customer_name = customer_name 
        self.customer_tax_num = customer_tax_num 
        self.customer_address_tel = customer_address_tel 
        self.bank_name_account = bank_name_account 
        self.goods_services_name = goods_services_name 
        self.remark = remark 
        self.post_type = post_type 
        self.waybill_number = waybill_number

    def get_status(self):
        """ Get 申请结果

        :return: string, status
        """
        return self.status

    def set_status(self, status):
        """ Set 申请结果

        :type status: string
        :param status: 申请结果
        """
        self.status = status

    def get_count(self):
        """ Get 发票张数

        :return: int, count
        """
        return self.count

    def set_count(self, count):
        """ Set 发票张数

        :type count: int
        :param count: 发票张数
        """
        self.count = count

    def get_price_tax_amount(self):
        """ Get 价税合计

        :return: string, price_tax_amount
        """
        return self.price_tax_amount

    def set_price_tax_amount(self, price_tax_amount):
        """ Set 价税合计

        :type price_tax_amount: string
        :param price_tax_amount: 价税合计
        """
        self.price_tax_amount = price_tax_amount

    def get_price_amount(self):
        """ Get 不含税金额

        :return: string, price_amount
        """
        return self.price_amount

    def set_price_amount(self, price_amount):
        """ Set 不含税金额

        :type price_amount: string
        :param price_amount: 不含税金额
        """
        self.price_amount = price_amount

    def get_tax_amount(self):
        """ Get 税额

        :return: string, tax_amount
        """
        return self.tax_amount

    def set_tax_amount(self, tax_amount):
        """ Set 税额

        :type tax_amount: string
        :param tax_amount: 税额
        """
        self.tax_amount = tax_amount

    def get_invoice_type(self):
        """ Get 发票类型

        :return: string, invoice_type
        """
        return self.invoice_type

    def set_invoice_type(self, invoice_type):
        """ Set 发票类型

        :type invoice_type: string
        :param invoice_type: 发票类型
        """
        self.invoice_type = invoice_type

    def get_customer_name(self):
        """ Get 购方名称

        :return: string, customer_name
        """
        return self.customer_name

    def set_customer_name(self, customer_name):
        """ Set 购方名称

        :type customer_name: string
        :param customer_name: 购方名称
        """
        self.customer_name = customer_name

    def get_customer_tax_num(self):
        """ Get 纳税人识别号

        :return: string, customer_tax_num
        """
        return self.customer_tax_num

    def set_customer_tax_num(self, customer_tax_num):
        """ Set 纳税人识别号

        :type customer_tax_num: string
        :param customer_tax_num: 纳税人识别号
        """
        self.customer_tax_num = customer_tax_num

    def get_customer_address_tel(self):
        """ Get 购方地址、电话

        :return: string, customer_address_tel
        """
        return self.customer_address_tel

    def set_customer_address_tel(self, customer_address_tel):
        """ Set 购方地址、电话

        :type customer_address_tel: string
        :param customer_address_tel: 购方地址、电话
        """
        self.customer_address_tel = customer_address_tel

    def get_bank_name_account(self):
        """ Get 开户行及账号

        :return: string, bank_name_account
        """
        return self.bank_name_account

    def set_bank_name_account(self, bank_name_account):
        """ Set 开户行及账号

        :type bank_name_account: string
        :param bank_name_account: 开户行及账号
        """
        self.bank_name_account = bank_name_account

    def get_goods_services_name(self):
        """ Get 货物或应税劳务、服务名称

        :return: string, goods_services_name
        """
        return self.goods_services_name

    def set_goods_services_name(self, goods_services_name):
        """ Set 货物或应税劳务、服务名称

        :type goods_services_name: string
        :param goods_services_name: 货物或应税劳务、服务名称
        """
        self.goods_services_name = goods_services_name

    def get_remark(self):
        """ Get 发票备注

        :return: string, remark
        """
        return self.remark

    def set_remark(self, remark):
        """ Set 发票备注

        :type remark: string
        :param remark: 发票备注
        """
        self.remark = remark

    def get_post_type(self):
        """ Get 邮寄类型

        :return: string, post_type
        """
        return self.post_type

    def set_post_type(self, post_type):
        """ Set 邮寄类型

        :type post_type: string
        :param post_type: 邮寄类型
        """
        self.post_type = post_type

    def get_waybill_number(self):
        """ Get 快递单号

        :return: list, waybill_number
        """
        return self.waybill_number

    def set_waybill_number(self, waybill_number):
        """ Set 快递单号

        :type waybill_number: list
        :param waybill_number: 快递单号
        """
        self.waybill_number = waybill_number 

class BankNameAccount(BaseRequest):
    """
    
    :type item: string
    :param item: 开户行及账号
    
    :type default: bool
    :param default: 是否为默认值
    """
    def __init__(self, item=None, default=None):
        super().__init__() 
        self.item = item 
        self.default = default

    def get_item(self):
        """ Get 开户行及账号

        :return: string, item
        """
        return self.item

    def set_item(self, item):
        """ Set 开户行及账号

        :type item: string
        :param item: 开户行及账号
        """
        self.item = item

    def get_default(self):
        """ Get 是否为默认值

        :return: bool, default
        """
        return self.default

    def set_default(self, default):
        """ Set 是否为默认值

        :type default: bool
        :param default: 是否为默认值
        """
        self.default = default 

class GoodsServicesName(BaseRequest):
    """
    
    :type item: string
    :param item: 货物或应税劳务、服务名称
    
    :type default: bool
    :param default: 是否为默认值
    """
    def __init__(self, item=None, default=None):
        super().__init__() 
        self.item = item 
        self.default = default

    def get_item(self):
        """ Get 货物或应税劳务、服务名称

        :return: string, item
        """
        return self.item

    def set_item(self, item):
        """ Set 货物或应税劳务、服务名称

        :type item: string
        :param item: 货物或应税劳务、服务名称
        """
        self.item = item

    def get_default(self):
        """ Get 是否为默认值

        :return: bool, default
        """
        return self.default

    def set_default(self, default):
        """ Set 是否为默认值

        :type default: bool
        :param default: 是否为默认值
        """
        self.default = default 

class GetInvoiceFileRequest(BaseRequest):
    """
    
    :type invoice_apply_id: string
    :param invoice_apply_id: 发票申请编号
    
    :type application_id: string
    :param application_id: 发票申请单 ID
    """
    def __init__(self, invoice_apply_id=None, application_id=None):
        super().__init__() 
        self.invoice_apply_id = invoice_apply_id 
        self.application_id = application_id

    def get_invoice_apply_id(self):
        """ Get 发票申请编号

        :return: string, invoice_apply_id
        """
        return self.invoice_apply_id

    def set_invoice_apply_id(self, invoice_apply_id):
        """ Set 发票申请编号

        :type invoice_apply_id: string
        :param invoice_apply_id: 发票申请编号
        """
        self.invoice_apply_id = invoice_apply_id

    def get_application_id(self):
        """ Get 发票申请单 ID

        :return: string, application_id
        """
        return self.application_id

    def set_application_id(self, application_id):
        """ Set 发票申请单 ID

        :type application_id: string
        :param application_id: 发票申请单 ID
        """
        self.application_id = application_id 

class GetInvoiceFileResponse(BaseRequest):
    """
    
    :type url: string
    :param url: 下载地址
    
    :type name: string
    :param name: 文件名称
    """
    def __init__(self, url=None, name=None):
        super().__init__() 
        self.url = url 
        self.name = name

    def get_url(self):
        """ Get 下载地址

        :return: string, url
        """
        return self.url

    def set_url(self, url):
        """ Set 下载地址

        :type url: string
        :param url: 下载地址
        """
        self.url = url

    def get_name(self):
        """ Get 文件名称

        :return: string, name
        """
        return self.name

    def set_name(self, name):
        """ Set 文件名称

        :type name: string
        :param name: 文件名称
        """
        self.name = name 

class SendReminderEmailRequest(BaseRequest):
    """
    
    :type invoice_apply_id: string
    :param invoice_apply_id: 发票申请编号
    
    :type application_id: string
    :param application_id: 发票申请单 ID
    """
    def __init__(self, invoice_apply_id=None, application_id=None):
        super().__init__() 
        self.invoice_apply_id = invoice_apply_id 
        self.application_id = application_id

    def get_invoice_apply_id(self):
        """ Get 发票申请编号

        :return: string, invoice_apply_id
        """
        return self.invoice_apply_id

    def set_invoice_apply_id(self, invoice_apply_id):
        """ Set 发票申请编号

        :type invoice_apply_id: string
        :param invoice_apply_id: 发票申请编号
        """
        self.invoice_apply_id = invoice_apply_id

    def get_application_id(self):
        """ Get 发票申请单 ID

        :return: string, application_id
        """
        return self.application_id

    def set_application_id(self, application_id):
        """ Set 发票申请单 ID

        :type application_id: string
        :param application_id: 发票申请单 ID
        """
        self.application_id = application_id 

class SendReminderEmailResponse(BaseRequest):
    """
    """
    def __init__(self):
        super().__init__() 

class NotifyInvoiceDoneRequest(BaseRequest):
    """
    
    :type application_id: string
    :param application_id: 发票申请单 ID
    
    :type invoice_apply_id: string
    :param invoice_apply_id: 发票申请编号
    
    :type status: string
    :param status: 申请结果
    
    :type count: int
    :param count: 发票张数
    
    :type price_tax_amount: string
    :param price_tax_amount: 价税合计
    
    :type price_amount: string
    :param price_amount: 不含税金额
    
    :type tax_amount: string
    :param tax_amount: 税额
    
    :type invoice_type: string
    :param invoice_type: 发票类型
    
    :type customer_name: string
    :param customer_name: 购方名称
    
    :type customer_tax_num: string
    :param customer_tax_num: 纳税人识别号
    
    :type customer_address_tel: string
    :param customer_address_tel: 购方地址、电话
    
    :type bank_name_account: string
    :param bank_name_account: 开户行及账号
    
    :type goods_services_name: string
    :param goods_services_name: 货物或应税劳务、服务名称
    
    :type remark: string
    :param remark: 发票备注
    
    :type post_type: string
    :param post_type: 邮寄类型
    
    :type waybill_number: list
    :param waybill_number: 快递单号
    
    :type reject_reason: string
    :param reject_reason: 驳回原因
    """
    def __init__(self, application_id=None, invoice_apply_id=None, status=None, count=None, price_tax_amount=None, price_amount=None, tax_amount=None, invoice_type=None, customer_name=None, customer_tax_num=None, customer_address_tel=None, bank_name_account=None, goods_services_name=None, remark=None, post_type=None, waybill_number=None, reject_reason=None):
        super().__init__() 
        self.application_id = application_id 
        self.invoice_apply_id = invoice_apply_id 
        self.status = status 
        self.count = count 
        self.price_tax_amount = price_tax_amount 
        self.price_amount = price_amount 
        self.tax_amount = tax_amount 
        self.invoice_type = invoice_type 
        self.customer_name = customer_name 
        self.customer_tax_num = customer_tax_num 
        self.customer_address_tel = customer_address_tel 
        self.bank_name_account = bank_name_account 
        self.goods_services_name = goods_services_name 
        self.remark = remark 
        self.post_type = post_type 
        self.waybill_number = waybill_number 
        self.reject_reason = reject_reason

    def get_application_id(self):
        """ Get 发票申请单 ID

        :return: string, application_id
        """
        return self.application_id

    def set_application_id(self, application_id):
        """ Set 发票申请单 ID

        :type application_id: string
        :param application_id: 发票申请单 ID
        """
        self.application_id = application_id

    def get_invoice_apply_id(self):
        """ Get 发票申请编号

        :return: string, invoice_apply_id
        """
        return self.invoice_apply_id

    def set_invoice_apply_id(self, invoice_apply_id):
        """ Set 发票申请编号

        :type invoice_apply_id: string
        :param invoice_apply_id: 发票申请编号
        """
        self.invoice_apply_id = invoice_apply_id

    def get_status(self):
        """ Get 申请结果

        :return: string, status
        """
        return self.status

    def set_status(self, status):
        """ Set 申请结果

        :type status: string
        :param status: 申请结果
        """
        self.status = status

    def get_count(self):
        """ Get 发票张数

        :return: int, count
        """
        return self.count

    def set_count(self, count):
        """ Set 发票张数

        :type count: int
        :param count: 发票张数
        """
        self.count = count

    def get_price_tax_amount(self):
        """ Get 价税合计

        :return: string, price_tax_amount
        """
        return self.price_tax_amount

    def set_price_tax_amount(self, price_tax_amount):
        """ Set 价税合计

        :type price_tax_amount: string
        :param price_tax_amount: 价税合计
        """
        self.price_tax_amount = price_tax_amount

    def get_price_amount(self):
        """ Get 不含税金额

        :return: string, price_amount
        """
        return self.price_amount

    def set_price_amount(self, price_amount):
        """ Set 不含税金额

        :type price_amount: string
        :param price_amount: 不含税金额
        """
        self.price_amount = price_amount

    def get_tax_amount(self):
        """ Get 税额

        :return: string, tax_amount
        """
        return self.tax_amount

    def set_tax_amount(self, tax_amount):
        """ Set 税额

        :type tax_amount: string
        :param tax_amount: 税额
        """
        self.tax_amount = tax_amount

    def get_invoice_type(self):
        """ Get 发票类型

        :return: string, invoice_type
        """
        return self.invoice_type

    def set_invoice_type(self, invoice_type):
        """ Set 发票类型

        :type invoice_type: string
        :param invoice_type: 发票类型
        """
        self.invoice_type = invoice_type

    def get_customer_name(self):
        """ Get 购方名称

        :return: string, customer_name
        """
        return self.customer_name

    def set_customer_name(self, customer_name):
        """ Set 购方名称

        :type customer_name: string
        :param customer_name: 购方名称
        """
        self.customer_name = customer_name

    def get_customer_tax_num(self):
        """ Get 纳税人识别号

        :return: string, customer_tax_num
        """
        return self.customer_tax_num

    def set_customer_tax_num(self, customer_tax_num):
        """ Set 纳税人识别号

        :type customer_tax_num: string
        :param customer_tax_num: 纳税人识别号
        """
        self.customer_tax_num = customer_tax_num

    def get_customer_address_tel(self):
        """ Get 购方地址、电话

        :return: string, customer_address_tel
        """
        return self.customer_address_tel

    def set_customer_address_tel(self, customer_address_tel):
        """ Set 购方地址、电话

        :type customer_address_tel: string
        :param customer_address_tel: 购方地址、电话
        """
        self.customer_address_tel = customer_address_tel

    def get_bank_name_account(self):
        """ Get 开户行及账号

        :return: string, bank_name_account
        """
        return self.bank_name_account

    def set_bank_name_account(self, bank_name_account):
        """ Set 开户行及账号

        :type bank_name_account: string
        :param bank_name_account: 开户行及账号
        """
        self.bank_name_account = bank_name_account

    def get_goods_services_name(self):
        """ Get 货物或应税劳务、服务名称

        :return: string, goods_services_name
        """
        return self.goods_services_name

    def set_goods_services_name(self, goods_services_name):
        """ Set 货物或应税劳务、服务名称

        :type goods_services_name: string
        :param goods_services_name: 货物或应税劳务、服务名称
        """
        self.goods_services_name = goods_services_name

    def get_remark(self):
        """ Get 发票备注

        :return: string, remark
        """
        return self.remark

    def set_remark(self, remark):
        """ Set 发票备注

        :type remark: string
        :param remark: 发票备注
        """
        self.remark = remark

    def get_post_type(self):
        """ Get 邮寄类型

        :return: string, post_type
        """
        return self.post_type

    def set_post_type(self, post_type):
        """ Set 邮寄类型

        :type post_type: string
        :param post_type: 邮寄类型
        """
        self.post_type = post_type

    def get_waybill_number(self):
        """ Get 快递单号

        :return: list, waybill_number
        """
        return self.waybill_number

    def set_waybill_number(self, waybill_number):
        """ Set 快递单号

        :type waybill_number: list
        :param waybill_number: 快递单号
        """
        self.waybill_number = waybill_number

    def get_reject_reason(self):
        """ Get 驳回原因

        :return: string, reject_reason
        """
        return self.reject_reason

    def set_reject_reason(self, reject_reason):
        """ Set 驳回原因

        :type reject_reason: string
        :param reject_reason: 驳回原因
        """
        self.reject_reason = reject_reason


from .model.invoice import *
from ..base import *
from ...utils import *


class InvoiceClient(BaseClient):
    def __init__(self, config):
        super().__init__(config)
    

    def get_invoice_stat(self, request: GetInvoiceStatRequest):
        """ 查询平台企业已开具和待开具发票金额
   
        :type request: GetInvoiceStatRequest
        :param request: the GetInvoiceStatRequest request parameters class.
    
        :return: GetInvoiceStatResponse
        """
        return self._get("/api/payment/v1/invoice-stat", request.request_id, Utils.copy_dict(request.__dict__))

    def get_invoice_amount(self, request: GetInvoiceAmountRequest):
        """ 查询可开具发票额度和发票开具信息
   
        :type request: GetInvoiceAmountRequest
        :param request: the GetInvoiceAmountRequest request parameters class.
    
        :return: GetInvoiceAmountResponse
        """
        return self._post("/api/invoice/v2/invoice-amount", request.request_id, Utils.copy_dict(request.__dict__))

    def apply_invoice(self, request: ApplyInvoiceRequest):
        """ 发票开具申请
   
        :type request: ApplyInvoiceRequest
        :param request: the ApplyInvoiceRequest request parameters class.
    
        :return: ApplyInvoiceResponse
        """
        return self._post("/api/invoice/v2/apply", request.request_id, Utils.copy_dict(request.__dict__))

    def get_invoice_status(self, request: GetInvoiceStatusRequest):
        """ 查询发票开具申请状态
   
        :type request: GetInvoiceStatusRequest
        :param request: the GetInvoiceStatusRequest request parameters class.
    
        :return: GetInvoiceStatusResponse
        """
        return self._post("/api/invoice/v2/invoice/invoice-status", request.request_id, Utils.copy_dict(request.__dict__))

    def get_invoice_file(self, request: GetInvoiceFileRequest):
        """ 下载 PDF 版发票
   
        :type request: GetInvoiceFileRequest
        :param request: the GetInvoiceFileRequest request parameters class.
    
        :return: GetInvoiceFileResponse
        """
        return self._post("/api/invoice/v2/invoice/invoice-pdf", request.request_id, Utils.copy_dict(request.__dict__))

    def send_reminder_email(self, request: SendReminderEmailRequest):
        """ 发送发票扫描件压缩包下载链接邮件
   
        :type request: SendReminderEmailRequest
        :param request: the SendReminderEmailRequest request parameters class.
    
        :return: SendReminderEmailResponse
        """
        return self._post("/api/invoice/v2/invoice/reminder/email", request.request_id, Utils.copy_dict(request.__dict__))
     


# 基础信息配置
class Config(object):
    """

    :type host: string
    :param host: 请求域名

    :type dealer_id: string
    :param dealer_id: 平台企业 ID

    :type sign_type: string
    :param sign_type: 签名类型

    :type app_key: string
    :param app_key: App Key

    :type des3key: string
    :param des3key: 3DES Key

    :type dealer_private_key: string
    :param dealer_private_key: 平台企业私钥

    :type yzh_public_key: string
    :param yzh_public_key: 云账户公钥
    """
    def __init__(self, host, dealer_id, sign_type, app_key, des3key, dealer_private_key: str, yzh_public_key: str):
        self.host = host
        self.dealer_id = dealer_id
        self.sign_type = sign_type
        self.app_key = app_key
        self.des3key = des3key
        self.dealer_private_key = dealer_private_key
        self.yzh_public_key = yzh_public_key
        self.check_config()

    def check_config(self):
        if self.dealer_private_key is not None:
            self.dealer_private_key = self.dealer_private_key.strip()
        if self.yzh_public_key is not None:
            self.yzh_public_key = self.yzh_public_key.strip()
        if self.sign_type != "sha256" and self.sign_type != "rsa":
            raise ValueError('wrong sign type')
        if self.host is None:
            self.host = "https://api-service.yunzhanghu.com"



from .model.bizlicxjjh5 import *
from ..base import *
from ...utils import *


class Bizlicxjjh5Client(BaseClient):
    def __init__(self, config):
        super().__init__(config)
    

    def h5_get_start_url(self, request: H5GetStartUrlRequest):
        """ 预启动
   
        :type request: H5GetStartUrlRequest
        :param request: the H5GetStartUrlRequest request parameters class.
    
        :return: H5GetStartUrlResponse
        """
        return self._get("/api/aic/new-economy/h5/v1/h5url", request.request_id, Utils.copy_dict(request.__dict__))

    def h5_eco_city_aic_status(self, request: H5EcoCityAicStatusRequest):
        """ 查询个体工商户状态
   
        :type request: H5EcoCityAicStatusRequest
        :param request: the H5EcoCityAicStatusRequest request parameters class.
    
        :return: H5EcoCityAicStatusResponse
        """
        return self._get("/api/aic/new-economy/h5/v1/status", request.request_id, Utils.copy_dict(request.__dict__))
     


from .model.h5usersign import *
from ..base import *
from ...utils import *


class H5UsersignClient(BaseClient):
    def __init__(self, config):
        super().__init__(config)
    

    def h5_user_presign(self, request: H5UserPresignRequest):
        """ 预申请签约
   
        :type request: H5UserPresignRequest
        :param request: the H5UserPresignRequest request parameters class.
    
        :return: H5UserPresignResponse
        """
        return self._post("/api/sdk/v1/presign", request.request_id, Utils.copy_dict(request.__dict__))

    def h5_user_sign(self, request: H5UserSignRequest):
        """ 申请签约
   
        :type request: H5UserSignRequest
        :param request: the H5UserSignRequest request parameters class.
    
        :return: H5UserSignResponse
        """
        return self._get("/api/sdk/v1/sign/h5", request.request_id, Utils.copy_dict(request.__dict__))

    def get_h5_user_sign_status(self, request: GetH5UserSignStatusRequest):
        """ 获取用户签约状态
   
        :type request: GetH5UserSignStatusRequest
        :param request: the GetH5UserSignStatusRequest request parameters class.
    
        :return: GetH5UserSignStatusResponse
        """
        return self._get("/api/sdk/v1/sign/user/status", request.request_id, Utils.copy_dict(request.__dict__))

    def h5_user_release(self, request: H5UserReleaseRequest):
        """ 用户解约（测试账号专用接口）
   
        :type request: H5UserReleaseRequest
        :param request: the H5UserReleaseRequest request parameters class.
    
        :return: H5UserReleaseResponse
        """
        return self._post("/api/sdk/v1/sign/release", request.request_id, Utils.copy_dict(request.__dict__))
     


from ...base import BaseRequest
 

class ApiUseSignContractRequest(BaseRequest):
    """
    
    :type dealer_id: string
    :param dealer_id: 平台企业 ID
    
    :type broker_id: string
    :param broker_id: 综合服务主体 ID
    """
    def __init__(self, dealer_id=None, broker_id=None):
        super().__init__() 
        self.dealer_id = dealer_id 
        self.broker_id = broker_id

    def get_dealer_id(self):
        """ Get 平台企业 ID

        :return: string, dealer_id
        """
        return self.dealer_id

    def set_dealer_id(self, dealer_id):
        """ Set 平台企业 ID

        :type dealer_id: string
        :param dealer_id: 平台企业 ID
        """
        self.dealer_id = dealer_id

    def get_broker_id(self):
        """ Get 综合服务主体 ID

        :return: string, broker_id
        """
        return self.broker_id

    def set_broker_id(self, broker_id):
        """ Set 综合服务主体 ID

        :type broker_id: string
        :param broker_id: 综合服务主体 ID
        """
        self.broker_id = broker_id 

class ApiUseSignContractResponse(BaseRequest):
    """
    
    :type url: string
    :param url: 预览跳转 URL
    
    :type title: string
    :param title: 协议名称
    """
    def __init__(self, url=None, title=None):
        super().__init__() 
        self.url = url 
        self.title = title

    def get_url(self):
        """ Get 预览跳转 URL

        :return: string, url
        """
        return self.url

    def set_url(self, url):
        """ Set 预览跳转 URL

        :type url: string
        :param url: 预览跳转 URL
        """
        self.url = url

    def get_title(self):
        """ Get 协议名称

        :return: string, title
        """
        return self.title

    def set_title(self, title):
        """ Set 协议名称

        :type title: string
        :param title: 协议名称
        """
        self.title = title 

class ApiUserSignRequest(BaseRequest):
    """
    
    :type broker_id: string
    :param broker_id: 综合服务主体 ID
    
    :type dealer_id: string
    :param dealer_id: 平台企业 ID
    
    :type real_name: string
    :param real_name: 姓名
    
    :type id_card: string
    :param id_card: 证件号码
    
    :type card_type: string
    :param card_type: 证件类型 idcard：身份证 passport：护照 mtphkm：港澳居民来往内地通行证  mtpt：台湾居民往来大陆通行证 rphkm：中华人民共和国港澳居民居住证 rpt：中华人民共和国台湾居民居住证 fpr：外国人永久居留身份证 ffwp：中华人民共和国外国人就业许可证书
    """
    def __init__(self, broker_id=None, dealer_id=None, real_name=None, id_card=None, card_type=None):
        super().__init__() 
        self.broker_id = broker_id 
        self.dealer_id = dealer_id 
        self.real_name = real_name 
        self.id_card = id_card 
        self.card_type = card_type

    def get_broker_id(self):
        """ Get 综合服务主体 ID

        :return: string, broker_id
        """
        return self.broker_id

    def set_broker_id(self, broker_id):
        """ Set 综合服务主体 ID

        :type broker_id: string
        :param broker_id: 综合服务主体 ID
        """
        self.broker_id = broker_id

    def get_dealer_id(self):
        """ Get 平台企业 ID

        :return: string, dealer_id
        """
        return self.dealer_id

    def set_dealer_id(self, dealer_id):
        """ Set 平台企业 ID

        :type dealer_id: string
        :param dealer_id: 平台企业 ID
        """
        self.dealer_id = dealer_id

    def get_real_name(self):
        """ Get 姓名

        :return: string, real_name
        """
        return self.real_name

    def set_real_name(self, real_name):
        """ Set 姓名

        :type real_name: string
        :param real_name: 姓名
        """
        self.real_name = real_name

    def get_id_card(self):
        """ Get 证件号码

        :return: string, id_card
        """
        return self.id_card

    def set_id_card(self, id_card):
        """ Set 证件号码

        :type id_card: string
        :param id_card: 证件号码
        """
        self.id_card = id_card

    def get_card_type(self):
        """ Get 证件类型 idcard：身份证 passport：护照 mtphkm：港澳居民来往内地通行证  mtpt：台湾居民往来大陆通行证 rphkm：中华人民共和国港澳居民居住证 rpt：中华人民共和国台湾居民居住证 fpr：外国人永久居留身份证 ffwp：中华人民共和国外国人就业许可证书

        :return: string, card_type
        """
        return self.card_type

    def set_card_type(self, card_type):
        """ Set 证件类型 idcard：身份证 passport：护照 mtphkm：港澳居民来往内地通行证  mtpt：台湾居民往来大陆通行证 rphkm：中华人民共和国港澳居民居住证 rpt：中华人民共和国台湾居民居住证 fpr：外国人永久居留身份证 ffwp：中华人民共和国外国人就业许可证书

        :type card_type: string
        :param card_type: 证件类型 idcard：身份证 passport：护照 mtphkm：港澳居民来往内地通行证  mtpt：台湾居民往来大陆通行证 rphkm：中华人民共和国港澳居民居住证 rpt：中华人民共和国台湾居民居住证 fpr：外国人永久居留身份证 ffwp：中华人民共和国外国人就业许可证书
        """
        self.card_type = card_type 

class ApiUserSignResponse(BaseRequest):
    """
    
    :type status: string
    :param status: 是否签约成功
    """
    def __init__(self, status=None):
        super().__init__() 
        self.status = status

    def get_status(self):
        """ Get 是否签约成功

        :return: string, status
        """
        return self.status

    def set_status(self, status):
        """ Set 是否签约成功

        :type status: string
        :param status: 是否签约成功
        """
        self.status = status 

class GetApiUserSignStatusRequest(BaseRequest):
    """
    
    :type dealer_id: string
    :param dealer_id: 平台企业 ID
    
    :type broker_id: string
    :param broker_id: 综合服务主体 ID
    
    :type real_name: string
    :param real_name: 姓名
    
    :type id_card: string
    :param id_card: 证件号码
    """
    def __init__(self, dealer_id=None, broker_id=None, real_name=None, id_card=None):
        super().__init__() 
        self.dealer_id = dealer_id 
        self.broker_id = broker_id 
        self.real_name = real_name 
        self.id_card = id_card

    def get_dealer_id(self):
        """ Get 平台企业 ID

        :return: string, dealer_id
        """
        return self.dealer_id

    def set_dealer_id(self, dealer_id):
        """ Set 平台企业 ID

        :type dealer_id: string
        :param dealer_id: 平台企业 ID
        """
        self.dealer_id = dealer_id

    def get_broker_id(self):
        """ Get 综合服务主体 ID

        :return: string, broker_id
        """
        return self.broker_id

    def set_broker_id(self, broker_id):
        """ Set 综合服务主体 ID

        :type broker_id: string
        :param broker_id: 综合服务主体 ID
        """
        self.broker_id = broker_id

    def get_real_name(self):
        """ Get 姓名

        :return: string, real_name
        """
        return self.real_name

    def set_real_name(self, real_name):
        """ Set 姓名

        :type real_name: string
        :param real_name: 姓名
        """
        self.real_name = real_name

    def get_id_card(self):
        """ Get 证件号码

        :return: string, id_card
        """
        return self.id_card

    def set_id_card(self, id_card):
        """ Set 证件号码

        :type id_card: string
        :param id_card: 证件号码
        """
        self.id_card = id_card 

class GetApiUserSignStatusResponse(BaseRequest):
    """
    
    :type signed_at: string
    :param signed_at: 签约时间
    
    :type status: string
    :param status: 用户签约状态
    """
    def __init__(self, signed_at=None, status=None):
        super().__init__() 
        self.signed_at = signed_at 
        self.status = status

    def get_signed_at(self):
        """ Get 签约时间

        :return: string, signed_at
        """
        return self.signed_at

    def set_signed_at(self, signed_at):
        """ Set 签约时间

        :type signed_at: string
        :param signed_at: 签约时间
        """
        self.signed_at = signed_at

    def get_status(self):
        """ Get 用户签约状态

        :return: string, status
        """
        return self.status

    def set_status(self, status):
        """ Set 用户签约状态

        :type status: string
        :param status: 用户签约状态
        """
        self.status = status 

class ApiUserSignReleaseRequest(BaseRequest):
    """
    
    :type broker_id: string
    :param broker_id: 综合服务主体 ID
    
    :type dealer_id: string
    :param dealer_id: 平台企业 ID
    
    :type real_name: string
    :param real_name: 姓名
    
    :type id_card: string
    :param id_card: 证件号码
    
    :type card_type: string
    :param card_type: 证件类型 idcard：身份证 passport：护照 mtphkm：港澳居民来往内地通行证  mtpt：台湾居民往来大陆通行证 rphkm：中华人民共和国港澳居民居住证 rpt：中华人民共和国台湾居民居住证 fpr：外国人永久居留身份证 ffwp：中华人民共和国外国人就业许可证书
    """
    def __init__(self, broker_id=None, dealer_id=None, real_name=None, id_card=None, card_type=None):
        super().__init__() 
        self.broker_id = broker_id 
        self.dealer_id = dealer_id 
        self.real_name = real_name 
        self.id_card = id_card 
        self.card_type = card_type

    def get_broker_id(self):
        """ Get 综合服务主体 ID

        :return: string, broker_id
        """
        return self.broker_id

    def set_broker_id(self, broker_id):
        """ Set 综合服务主体 ID

        :type broker_id: string
        :param broker_id: 综合服务主体 ID
        """
        self.broker_id = broker_id

    def get_dealer_id(self):
        """ Get 平台企业 ID

        :return: string, dealer_id
        """
        return self.dealer_id

    def set_dealer_id(self, dealer_id):
        """ Set 平台企业 ID

        :type dealer_id: string
        :param dealer_id: 平台企业 ID
        """
        self.dealer_id = dealer_id

    def get_real_name(self):
        """ Get 姓名

        :return: string, real_name
        """
        return self.real_name

    def set_real_name(self, real_name):
        """ Set 姓名

        :type real_name: string
        :param real_name: 姓名
        """
        self.real_name = real_name

    def get_id_card(self):
        """ Get 证件号码

        :return: string, id_card
        """
        return self.id_card

    def set_id_card(self, id_card):
        """ Set 证件号码

        :type id_card: string
        :param id_card: 证件号码
        """
        self.id_card = id_card

    def get_card_type(self):
        """ Get 证件类型 idcard：身份证 passport：护照 mtphkm：港澳居民来往内地通行证  mtpt：台湾居民往来大陆通行证 rphkm：中华人民共和国港澳居民居住证 rpt：中华人民共和国台湾居民居住证 fpr：外国人永久居留身份证 ffwp：中华人民共和国外国人就业许可证书

        :return: string, card_type
        """
        return self.card_type

    def set_card_type(self, card_type):
        """ Set 证件类型 idcard：身份证 passport：护照 mtphkm：港澳居民来往内地通行证  mtpt：台湾居民往来大陆通行证 rphkm：中华人民共和国港澳居民居住证 rpt：中华人民共和国台湾居民居住证 fpr：外国人永久居留身份证 ffwp：中华人民共和国外国人就业许可证书

        :type card_type: string
        :param card_type: 证件类型 idcard：身份证 passport：护照 mtphkm：港澳居民来往内地通行证  mtpt：台湾居民往来大陆通行证 rphkm：中华人民共和国港澳居民居住证 rpt：中华人民共和国台湾居民居住证 fpr：外国人永久居留身份证 ffwp：中华人民共和国外国人就业许可证书
        """
        self.card_type = card_type 

class ApiUserSignReleaseResponse(BaseRequest):
    """
    
    :type status: string
    :param status: 是否解约成功
    """
    def __init__(self, status=None):
        super().__init__() 
        self.status = status

    def get_status(self):
        """ Get 是否解约成功

        :return: string, status
        """
        return self.status

    def set_status(self, status):
        """ Set 是否解约成功

        :type status: string
        :param status: 是否解约成功
        """
        self.status = status


from .model.authentication import *
from ..base import *
from ...utils import *


class AuthenticationClient(BaseClient):
    def __init__(self, config):
        super().__init__(config)
    

    def bank_card_four_auth_verify(self, request: BankCardFourAuthVerifyRequest):
        """ 银行卡四要素鉴权请求（下发短信验证码）
   
        :type request: BankCardFourAuthVerifyRequest
        :param request: the BankCardFourAuthVerifyRequest request parameters class.
    
        :return: BankCardFourAuthVerifyResponse
        """
        return self._post("/authentication/verify-request", request.request_id, Utils.copy_dict(request.__dict__))

    def bank_card_four_auth_confirm(self, request: BankCardFourAuthConfirmRequest):
        """ 银行卡四要素确认请求（上传短信验证码）
   
        :type request: BankCardFourAuthConfirmRequest
        :param request: the BankCardFourAuthConfirmRequest request parameters class.
    
        :return: BankCardFourAuthConfirmResponse
        """
        return self._post("/authentication/verify-confirm", request.request_id, Utils.copy_dict(request.__dict__))

    def bank_card_four_verify(self, request: BankCardFourVerifyRequest):
        """ 银行卡四要素验证
   
        :type request: BankCardFourVerifyRequest
        :param request: the BankCardFourVerifyRequest request parameters class.
    
        :return: BankCardFourVerifyResponse
        """
        return self._post("/authentication/verify-bankcard-four-factor", request.request_id, Utils.copy_dict(request.__dict__))

    def bank_card_three_verify(self, request: BankCardThreeVerifyRequest):
        """ 银行卡三要素验证
   
        :type request: BankCardThreeVerifyRequest
        :param request: the BankCardThreeVerifyRequest request parameters class.
    
        :return: BankCardThreeVerifyResponse
        """
        return self._post("/authentication/verify-bankcard-three-factor", request.request_id, Utils.copy_dict(request.__dict__))

    def i_d_card_verify(self, request: IDCardVerifyRequest):
        """ 身份证实名验证
   
        :type request: IDCardVerifyRequest
        :param request: the IDCardVerifyRequest request parameters class.
    
        :return: IDCardVerifyResponse
        """
        return self._post("/authentication/verify-id", request.request_id, Utils.copy_dict(request.__dict__))

    def user_exempted_info(self, request: UserExemptedInfoRequest):
        """ 上传免验证用户名单信息
   
        :type request: UserExemptedInfoRequest
        :param request: the UserExemptedInfoRequest request parameters class.
    
        :return: UserExemptedInfoResponse
        """
        return self._post("/api/payment/v1/user/exempted/info", request.request_id, Utils.copy_dict(request.__dict__))

    def user_white_check(self, request: UserWhiteCheckRequest):
        """ 查看免验证用户名单是否存在
   
        :type request: UserWhiteCheckRequest
        :param request: the UserWhiteCheckRequest request parameters class.
    
        :return: UserWhiteCheckResponse
        """
        return self._post("/api/payment/v1/user/white/check", request.request_id, Utils.copy_dict(request.__dict__))

    def get_bank_card_info(self, request: GetBankCardInfoRequest):
        """ 银行卡信息查询接口
   
        :type request: GetBankCardInfoRequest
        :param request: the GetBankCardInfoRequest request parameters class.
    
        :return: GetBankCardInfoResponse
        """
        return self._get("/api/payment/v1/card", request.request_id, Utils.copy_dict(request.__dict__))
     


from .model.bizlicxjjh5api import *
from ..base import *
from ...utils import *


class Bizlicxjjh5ApiClient(BaseClient):
    def __init__(self, config):
        super().__init__(config)
    

    def h5_pre_collect_bizlic_msg(self, request: H5PreCollectBizlicMsgRequest):
        """ 工商实名信息录入
   
        :type request: H5PreCollectBizlicMsgRequest
        :param request: the H5PreCollectBizlicMsgRequest request parameters class.
    
        :return: H5PreCollectBizlicMsgResponse
        """
        return self._post("/api/aic/new-economy/api-h5/v1/collect", request.request_id, Utils.copy_dict(request.__dict__))

    def h5_a_p_i_get_start_url(self, request: H5APIGetStartUrlRequest):
        """ 预启动
   
        :type request: H5APIGetStartUrlRequest
        :param request: the H5APIGetStartUrlRequest request parameters class.
    
        :return: H5APIGetStartUrlResponse
        """
        return self._get("/api/aic/new-economy/api-h5/v1/h5url", request.request_id, Utils.copy_dict(request.__dict__))

    def h5_a_p_i_eco_city_aic_status(self, request: H5APIEcoCityAicStatusRequest):
        """ 查询个体工商户状态
   
        :type request: H5APIEcoCityAicStatusRequest
        :param request: the H5APIEcoCityAicStatusRequest request parameters class.
    
        :return: H5APIEcoCityAicStatusResponse
        """
        return self._get("/api/aic/new-economy/api-h5/v1/status", request.request_id, Utils.copy_dict(request.__dict__))
     


#!/usr/bin/env python
# encoding: utf-8
#
# Copyright (C) 云账户
# All rights reserved.

"""
Setup script for log service SDK.
"""

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup
from yunzhanghu_sdk import __version__

requirements = [
    'requests>=2.19.1',
    'pycryptodome==3.10.1',
]

packages = [
    'yunzhanghu_sdk',
    'yunzhanghu_sdk.client',
    'yunzhanghu_sdk.client.api',
    'yunzhanghu_sdk.client.api.model',
]

setup(
    name='yunzhanghu_sdk',
    version=__version__,
    description='云账户官方 SDK for Python',
    author='yunzhanghu',
    install_requires=requirements,
    classifiers=[
        "Programming Language :: Python :: 3",
    ],
    packages=packages,
    long_description=open('云账户SDK-for-Python.md', encoding='utf-8').read(),
    long_description_content_type='text/markdown',
)



from ...base import BaseRequest
 

class GetDailyOrderFileRequest(BaseRequest):
    """
    
    :type order_date: string
    :param order_date: 订单查询日期, 格式：yyyy-MM-dd
    """
    def __init__(self, order_date=None):
        super().__init__() 
        self.order_date = order_date

    def get_order_date(self):
        """ Get 订单查询日期, 格式：yyyy-MM-dd

        :return: string, order_date
        """
        return self.order_date

    def set_order_date(self, order_date):
        """ Set 订单查询日期, 格式：yyyy-MM-dd

        :type order_date: string
        :param order_date: 订单查询日期, 格式：yyyy-MM-dd
        """
        self.order_date = order_date 

class GetDailyOrderFileResponse(BaseRequest):
    """
    
    :type order_download_url: string
    :param order_download_url: 下载地址
    """
    def __init__(self, order_download_url=None):
        super().__init__() 
        self.order_download_url = order_download_url

    def get_order_download_url(self):
        """ Get 下载地址

        :return: string, order_download_url
        """
        return self.order_download_url

    def set_order_download_url(self, order_download_url):
        """ Set 下载地址

        :type order_download_url: string
        :param order_download_url: 下载地址
        """
        self.order_download_url = order_download_url 

class GetDailyBillFileV2Request(BaseRequest):
    """
    
    :type bill_date: string
    :param bill_date: 所需获取的日流水日期，格式：yyyy-MM-dd
    """
    def __init__(self, bill_date=None):
        super().__init__() 
        self.bill_date = bill_date

    def get_bill_date(self):
        """ Get 所需获取的日流水日期，格式：yyyy-MM-dd

        :return: string, bill_date
        """
        return self.bill_date

    def set_bill_date(self, bill_date):
        """ Set 所需获取的日流水日期，格式：yyyy-MM-dd

        :type bill_date: string
        :param bill_date: 所需获取的日流水日期，格式：yyyy-MM-dd
        """
        self.bill_date = bill_date 

class GetDailyBillFileV2Response(BaseRequest):
    """
    
    :type bill_download_url: string
    :param bill_download_url: 下载地址
    """
    def __init__(self, bill_download_url=None):
        super().__init__() 
        self.bill_download_url = bill_download_url

    def get_bill_download_url(self):
        """ Get 下载地址

        :return: string, bill_download_url
        """
        return self.bill_download_url

    def set_bill_download_url(self, bill_download_url):
        """ Set 下载地址

        :type bill_download_url: string
        :param bill_download_url: 下载地址
        """
        self.bill_download_url = bill_download_url 

class ListDealerRechargeRecordV2Request(BaseRequest):
    """
    
    :type begin_at: string
    :param begin_at: 开始时间，格式：yyyy-MM-dd
    
    :type end_at: string
    :param end_at: 结束时间，格式：yyyy-MM-dd
    """
    def __init__(self, begin_at=None, end_at=None):
        super().__init__() 
        self.begin_at = begin_at 
        self.end_at = end_at

    def get_begin_at(self):
        """ Get 开始时间，格式：yyyy-MM-dd

        :return: string, begin_at
        """
        return self.begin_at

    def set_begin_at(self, begin_at):
        """ Set 开始时间，格式：yyyy-MM-dd

        :type begin_at: string
        :param begin_at: 开始时间，格式：yyyy-MM-dd
        """
        self.begin_at = begin_at

    def get_end_at(self):
        """ Get 结束时间，格式：yyyy-MM-dd

        :return: string, end_at
        """
        return self.end_at

    def set_end_at(self, end_at):
        """ Set 结束时间，格式：yyyy-MM-dd

        :type end_at: string
        :param end_at: 结束时间，格式：yyyy-MM-dd
        """
        self.end_at = end_at 

class ListDealerRechargeRecordV2Response(BaseRequest):
    """
    
    :type data: list
    :param data: 预付业务服务费记录
    """
    def __init__(self, data=None):
        super().__init__() 
        self.data = data

    def get_data(self):
        """ Get 预付业务服务费记录

        :return: list, data
        """
        return self.data

    def set_data(self, data):
        """ Set 预付业务服务费记录

        :type data: list
        :param data: 预付业务服务费记录
        """
        self.data = data 

class RechargeRecordInfo(BaseRequest):
    """
    
    :type dealer_id: string
    :param dealer_id: 平台企业 ID
    
    :type broker_id: string
    :param broker_id: 综合服务主体 ID
    
    :type recharge_id: string
    :param recharge_id: 预付业务服务费记录 ID
    
    :type amount: string
    :param amount: 预付业务服务费
    
    :type actual_amount: string
    :param actual_amount: 实际到账金额
    
    :type created_at: string
    :param created_at: 创建时间
    
    :type recharge_channel: string
    :param recharge_channel: 资金用途
    
    :type remark: string
    :param remark: 预付业务服务费备注
    
    :type recharge_account_no: string
    :param recharge_account_no: 平台企业付款银行账号
    """
    def __init__(self, dealer_id=None, broker_id=None, recharge_id=None, amount=None, actual_amount=None, created_at=None, recharge_channel=None, remark=None, recharge_account_no=None):
        super().__init__() 
        self.dealer_id = dealer_id 
        self.broker_id = broker_id 
        self.recharge_id = recharge_id 
        self.amount = amount 
        self.actual_amount = actual_amount 
        self.created_at = created_at 
        self.recharge_channel = recharge_channel 
        self.remark = remark 
        self.recharge_account_no = recharge_account_no

    def get_dealer_id(self):
        """ Get 平台企业 ID

        :return: string, dealer_id
        """
        return self.dealer_id

    def set_dealer_id(self, dealer_id):
        """ Set 平台企业 ID

        :type dealer_id: string
        :param dealer_id: 平台企业 ID
        """
        self.dealer_id = dealer_id

    def get_broker_id(self):
        """ Get 综合服务主体 ID

        :return: string, broker_id
        """
        return self.broker_id

    def set_broker_id(self, broker_id):
        """ Set 综合服务主体 ID

        :type broker_id: string
        :param broker_id: 综合服务主体 ID
        """
        self.broker_id = broker_id

    def get_recharge_id(self):
        """ Get 预付业务服务费记录 ID

        :return: string, recharge_id
        """
        return self.recharge_id

    def set_recharge_id(self, recharge_id):
        """ Set 预付业务服务费记录 ID

        :type recharge_id: string
        :param recharge_id: 预付业务服务费记录 ID
        """
        self.recharge_id = recharge_id

    def get_amount(self):
        """ Get 预付业务服务费

        :return: string, amount
        """
        return self.amount

    def set_amount(self, amount):
        """ Set 预付业务服务费

        :type amount: string
        :param amount: 预付业务服务费
        """
        self.amount = amount

    def get_actual_amount(self):
        """ Get 实际到账金额

        :return: string, actual_amount
        """
        return self.actual_amount

    def set_actual_amount(self, actual_amount):
        """ Set 实际到账金额

        :type actual_amount: string
        :param actual_amount: 实际到账金额
        """
        self.actual_amount = actual_amount

    def get_created_at(self):
        """ Get 创建时间

        :return: string, created_at
        """
        return self.created_at

    def set_created_at(self, created_at):
        """ Set 创建时间

        :type created_at: string
        :param created_at: 创建时间
        """
        self.created_at = created_at

    def get_recharge_channel(self):
        """ Get 资金用途

        :return: string, recharge_channel
        """
        return self.recharge_channel

    def set_recharge_channel(self, recharge_channel):
        """ Set 资金用途

        :type recharge_channel: string
        :param recharge_channel: 资金用途
        """
        self.recharge_channel = recharge_channel

    def get_remark(self):
        """ Get 预付业务服务费备注

        :return: string, remark
        """
        return self.remark

    def set_remark(self, remark):
        """ Set 预付业务服务费备注

        :type remark: string
        :param remark: 预付业务服务费备注
        """
        self.remark = remark

    def get_recharge_account_no(self):
        """ Get 平台企业付款银行账号

        :return: string, recharge_account_no
        """
        return self.recharge_account_no

    def set_recharge_account_no(self, recharge_account_no):
        """ Set 平台企业付款银行账号

        :type recharge_account_no: string
        :param recharge_account_no: 平台企业付款银行账号
        """
        self.recharge_account_no = recharge_account_no 

class ListDailyOrderRequest(BaseRequest):
    """
    
    :type order_date: string
    :param order_date: 订单查询日期, 格式：yyyy-MM-dd格式：yyyy-MM-dd
    
    :type offset: int
    :param offset: 偏移量
    
    :type length: int
    :param length: 长度
    
    :type channel: string
    :param channel: 支付路径名，银行卡（默认）、支付宝、微信
    
    :type data_type: string
    :param data_type: 如果为 encryption，则对返回的 data 进行加密
    """
    def __init__(self, order_date=None, offset=None, length=None, channel=None, data_type=None):
        super().__init__() 
        self.order_date = order_date 
        self.offset = offset 
        self.length = length 
        self.channel = channel 
        self.data_type = data_type

    def get_order_date(self):
        """ Get 订单查询日期, 格式：yyyy-MM-dd格式：yyyy-MM-dd

        :return: string, order_date
        """
        return self.order_date

    def set_order_date(self, order_date):
        """ Set 订单查询日期, 格式：yyyy-MM-dd格式：yyyy-MM-dd

        :type order_date: string
        :param order_date: 订单查询日期, 格式：yyyy-MM-dd格式：yyyy-MM-dd
        """
        self.order_date = order_date

    def get_offset(self):
        """ Get 偏移量

        :return: int, offset
        """
        return self.offset

    def set_offset(self, offset):
        """ Set 偏移量

        :type offset: int
        :param offset: 偏移量
        """
        self.offset = offset

    def get_length(self):
        """ Get 长度

        :return: int, length
        """
        return self.length

    def set_length(self, length):
        """ Set 长度

        :type length: int
        :param length: 长度
        """
        self.length = length

    def get_channel(self):
        """ Get 支付路径名，银行卡（默认）、支付宝、微信

        :return: string, channel
        """
        return self.channel

    def set_channel(self, channel):
        """ Set 支付路径名，银行卡（默认）、支付宝、微信

        :type channel: string
        :param channel: 支付路径名，银行卡（默认）、支付宝、微信
        """
        self.channel = channel

    def get_data_type(self):
        """ Get 如果为 encryption，则对返回的 data 进行加密

        :return: string, data_type
        """
        return self.data_type

    def set_data_type(self, data_type):
        """ Set 如果为 encryption，则对返回的 data 进行加密

        :type data_type: string
        :param data_type: 如果为 encryption，则对返回的 data 进行加密
        """
        self.data_type = data_type 

class ListDailyOrderResponse(BaseRequest):
    """
    
    :type total_num: int
    :param total_num: 总数目
    
    :type list: list
    :param list: 条目信息
    """
    def __init__(self, total_num=None, list=None):
        super().__init__() 
        self.total_num = total_num 
        self.list = list

    def get_total_num(self):
        """ Get 总数目

        :return: int, total_num
        """
        return self.total_num

    def set_total_num(self, total_num):
        """ Set 总数目

        :type total_num: int
        :param total_num: 总数目
        """
        self.total_num = total_num

    def get_list(self):
        """ Get 条目信息

        :return: list, list
        """
        return self.list

    def set_list(self, list):
        """ Set 条目信息

        :type list: list
        :param list: 条目信息
        """
        self.list = list 

class DealerOrderInfo(BaseRequest):
    """
    
    :type broker_id: string
    :param broker_id: 综合服务主体 ID
    
    :type dealer_id: string
    :param dealer_id: 平台企业 ID
    
    :type order_id: string
    :param order_id: 平台企业订单号
    
    :type ref: string
    :param ref: 订单流水号
    
    :type batch_id: string
    :param batch_id: 批次ID
    
    :type real_name: string
    :param real_name: 姓名
    
    :type card_no: string
    :param card_no: 收款账号
    
    :type broker_amount: string
    :param broker_amount: 综合服务主体订单金额
    
    :type broker_fee: string
    :param broker_fee: 综合服务主体加成服务费
    
    :type bill: string
    :param bill: 支付路径流水号
    
    :type status: string
    :param status: 订单状态
    
    :type status_message: string
    :param status_message: 订单状态码描述
    
    :type status_detail: string
    :param status_detail: 订单详情
    
    :type status_detail_message: string
    :param status_detail_message: 订单详细状态码描述
    
    :type statement_id: string
    :param statement_id: 短周期授信账单号
    
    :type fee_statement_id: string
    :param fee_statement_id: 服务费账单号
    
    :type bal_statement_id: string
    :param bal_statement_id: 余额账单号
    
    :type channel: string
    :param channel: 支付路径
    
    :type created_at: string
    :param created_at: 创建时间
    
    :type finished_time: string
    :param finished_time: 完成时间
    """
    def __init__(self, broker_id=None, dealer_id=None, order_id=None, ref=None, batch_id=None, real_name=None, card_no=None, broker_amount=None, broker_fee=None, bill=None, status=None, status_message=None, status_detail=None, status_detail_message=None, statement_id=None, fee_statement_id=None, bal_statement_id=None, channel=None, created_at=None, finished_time=None):
        super().__init__() 
        self.broker_id = broker_id 
        self.dealer_id = dealer_id 
        self.order_id = order_id 
        self.ref = ref 
        self.batch_id = batch_id 
        self.real_name = real_name 
        self.card_no = card_no 
        self.broker_amount = broker_amount 
        self.broker_fee = broker_fee 
        self.bill = bill 
        self.status = status 
        self.status_message = status_message 
        self.status_detail = status_detail 
        self.status_detail_message = status_detail_message 
        self.statement_id = statement_id 
        self.fee_statement_id = fee_statement_id 
        self.bal_statement_id = bal_statement_id 
        self.channel = channel 
        self.created_at = created_at 
        self.finished_time = finished_time

    def get_broker_id(self):
        """ Get 综合服务主体 ID

        :return: string, broker_id
        """
        return self.broker_id

    def set_broker_id(self, broker_id):
        """ Set 综合服务主体 ID

        :type broker_id: string
        :param broker_id: 综合服务主体 ID
        """
        self.broker_id = broker_id

    def get_dealer_id(self):
        """ Get 平台企业 ID

        :return: string, dealer_id
        """
        return self.dealer_id

    def set_dealer_id(self, dealer_id):
        """ Set 平台企业 ID

        :type dealer_id: string
        :param dealer_id: 平台企业 ID
        """
        self.dealer_id = dealer_id

    def get_order_id(self):
        """ Get 平台企业订单号

        :return: string, order_id
        """
        return self.order_id

    def set_order_id(self, order_id):
        """ Set 平台企业订单号

        :type order_id: string
        :param order_id: 平台企业订单号
        """
        self.order_id = order_id

    def get_ref(self):
        """ Get 订单流水号

        :return: string, ref
        """
        return self.ref

    def set_ref(self, ref):
        """ Set 订单流水号

        :type ref: string
        :param ref: 订单流水号
        """
        self.ref = ref

    def get_batch_id(self):
        """ Get 批次ID

        :return: string, batch_id
        """
        return self.batch_id

    def set_batch_id(self, batch_id):
        """ Set 批次ID

        :type batch_id: string
        :param batch_id: 批次ID
        """
        self.batch_id = batch_id

    def get_real_name(self):
        """ Get 姓名

        :return: string, real_name
        """
        return self.real_name

    def set_real_name(self, real_name):
        """ Set 姓名

        :type real_name: string
        :param real_name: 姓名
        """
        self.real_name = real_name

    def get_card_no(self):
        """ Get 收款账号

        :return: string, card_no
        """
        return self.card_no

    def set_card_no(self, card_no):
        """ Set 收款账号

        :type card_no: string
        :param card_no: 收款账号
        """
        self.card_no = card_no

    def get_broker_amount(self):
        """ Get 综合服务主体订单金额

        :return: string, broker_amount
        """
        return self.broker_amount

    def set_broker_amount(self, broker_amount):
        """ Set 综合服务主体订单金额

        :type broker_amount: string
        :param broker_amount: 综合服务主体订单金额
        """
        self.broker_amount = broker_amount

    def get_broker_fee(self):
        """ Get 综合服务主体加成服务费

        :return: string, broker_fee
        """
        return self.broker_fee

    def set_broker_fee(self, broker_fee):
        """ Set 综合服务主体加成服务费

        :type broker_fee: string
        :param broker_fee: 综合服务主体加成服务费
        """
        self.broker_fee = broker_fee

    def get_bill(self):
        """ Get 支付路径流水号

        :return: string, bill
        """
        return self.bill

    def set_bill(self, bill):
        """ Set 支付路径流水号

        :type bill: string
        :param bill: 支付路径流水号
        """
        self.bill = bill

    def get_status(self):
        """ Get 订单状态

        :return: string, status
        """
        return self.status

    def set_status(self, status):
        """ Set 订单状态

        :type status: string
        :param status: 订单状态
        """
        self.status = status

    def get_status_message(self):
        """ Get 订单状态码描述

        :return: string, status_message
        """
        return self.status_message

    def set_status_message(self, status_message):
        """ Set 订单状态码描述

        :type status_message: string
        :param status_message: 订单状态码描述
        """
        self.status_message = status_message

    def get_status_detail(self):
        """ Get 订单详情

        :return: string, status_detail
        """
        return self.status_detail

    def set_status_detail(self, status_detail):
        """ Set 订单详情

        :type status_detail: string
        :param status_detail: 订单详情
        """
        self.status_detail = status_detail

    def get_status_detail_message(self):
        """ Get 订单详细状态码描述

        :return: string, status_detail_message
        """
        return self.status_detail_message

    def set_status_detail_message(self, status_detail_message):
        """ Set 订单详细状态码描述

        :type status_detail_message: string
        :param status_detail_message: 订单详细状态码描述
        """
        self.status_detail_message = status_detail_message

    def get_statement_id(self):
        """ Get 短周期授信账单号

        :return: string, statement_id
        """
        return self.statement_id

    def set_statement_id(self, statement_id):
        """ Set 短周期授信账单号

        :type statement_id: string
        :param statement_id: 短周期授信账单号
        """
        self.statement_id = statement_id

    def get_fee_statement_id(self):
        """ Get 服务费账单号

        :return: string, fee_statement_id
        """
        return self.fee_statement_id

    def set_fee_statement_id(self, fee_statement_id):
        """ Set 服务费账单号

        :type fee_statement_id: string
        :param fee_statement_id: 服务费账单号
        """
        self.fee_statement_id = fee_statement_id

    def get_bal_statement_id(self):
        """ Get 余额账单号

        :return: string, bal_statement_id
        """
        return self.bal_statement_id

    def set_bal_statement_id(self, bal_statement_id):
        """ Set 余额账单号

        :type bal_statement_id: string
        :param bal_statement_id: 余额账单号
        """
        self.bal_statement_id = bal_statement_id

    def get_channel(self):
        """ Get 支付路径

        :return: string, channel
        """
        return self.channel

    def set_channel(self, channel):
        """ Set 支付路径

        :type channel: string
        :param channel: 支付路径
        """
        self.channel = channel

    def get_created_at(self):
        """ Get 创建时间

        :return: string, created_at
        """
        return self.created_at

    def set_created_at(self, created_at):
        """ Set 创建时间

        :type created_at: string
        :param created_at: 创建时间
        """
        self.created_at = created_at

    def get_finished_time(self):
        """ Get 完成时间

        :return: string, finished_time
        """
        return self.finished_time

    def set_finished_time(self, finished_time):
        """ Set 完成时间

        :type finished_time: string
        :param finished_time: 完成时间
        """
        self.finished_time = finished_time 

class ListDailyBillRequest(BaseRequest):
    """
    
    :type bill_date: string
    :param bill_date: 流水查询日期
    
    :type offset: int
    :param offset: 偏移量
    
    :type length: int
    :param length: 长度
    
    :type data_type: string
    :param data_type: 如果为 encryption，则对返回的 data 进行加密
    """
    def __init__(self, bill_date=None, offset=None, length=None, data_type=None):
        super().__init__() 
        self.bill_date = bill_date 
        self.offset = offset 
        self.length = length 
        self.data_type = data_type

    def get_bill_date(self):
        """ Get 流水查询日期

        :return: string, bill_date
        """
        return self.bill_date

    def set_bill_date(self, bill_date):
        """ Set 流水查询日期

        :type bill_date: string
        :param bill_date: 流水查询日期
        """
        self.bill_date = bill_date

    def get_offset(self):
        """ Get 偏移量

        :return: int, offset
        """
        return self.offset

    def set_offset(self, offset):
        """ Set 偏移量

        :type offset: int
        :param offset: 偏移量
        """
        self.offset = offset

    def get_length(self):
        """ Get 长度

        :return: int, length
        """
        return self.length

    def set_length(self, length):
        """ Set 长度

        :type length: int
        :param length: 长度
        """
        self.length = length

    def get_data_type(self):
        """ Get 如果为 encryption，则对返回的 data 进行加密

        :return: string, data_type
        """
        return self.data_type

    def set_data_type(self, data_type):
        """ Set 如果为 encryption，则对返回的 data 进行加密

        :type data_type: string
        :param data_type: 如果为 encryption，则对返回的 data 进行加密
        """
        self.data_type = data_type 

class ListDailyBillResponse(BaseRequest):
    """
    
    :type total_num: int
    :param total_num: 总条数
    
    :type list: list
    :param list: 条目信息
    """
    def __init__(self, total_num=None, list=None):
        super().__init__() 
        self.total_num = total_num 
        self.list = list

    def get_total_num(self):
        """ Get 总条数

        :return: int, total_num
        """
        return self.total_num

    def set_total_num(self, total_num):
        """ Set 总条数

        :type total_num: int
        :param total_num: 总条数
        """
        self.total_num = total_num

    def get_list(self):
        """ Get 条目信息

        :return: list, list
        """
        return self.list

    def set_list(self, list):
        """ Set 条目信息

        :type list: list
        :param list: 条目信息
        """
        self.list = list 

class DealerBillInfo(BaseRequest):
    """
    
    :type broker_id: string
    :param broker_id: 综合服务主体 ID
    
    :type dealer_id: string
    :param dealer_id: 平台企业 ID
    
    :type order_id: string
    :param order_id: 平台企业订单号
    
    :type ref: string
    :param ref: 资金流水号
    
    :type broker_product_name: string
    :param broker_product_name: 综合服务主体名称
    
    :type dealer_product_name: string
    :param dealer_product_name: 平台企业名称
    
    :type biz_ref: string
    :param biz_ref: 业务订单流水号
    
    :type acct_type: string
    :param acct_type: 账户类型
    
    :type amount: string
    :param amount: 入账金额
    
    :type balance: string
    :param balance: 账户余额
    
    :type business_category: string
    :param business_category: 业务分类
    
    :type business_type: string
    :param business_type: 业务类型
    
    :type consumption_type: string
    :param consumption_type: 收支类型
    
    :type created_at: string
    :param created_at: 入账时间
    
    :type remark: string
    :param remark: 备注
    """
    def __init__(self, broker_id=None, dealer_id=None, order_id=None, ref=None, broker_product_name=None, dealer_product_name=None, biz_ref=None, acct_type=None, amount=None, balance=None, business_category=None, business_type=None, consumption_type=None, created_at=None, remark=None):
        super().__init__() 
        self.broker_id = broker_id 
        self.dealer_id = dealer_id 
        self.order_id = order_id 
        self.ref = ref 
        self.broker_product_name = broker_product_name 
        self.dealer_product_name = dealer_product_name 
        self.biz_ref = biz_ref 
        self.acct_type = acct_type 
        self.amount = amount 
        self.balance = balance 
        self.business_category = business_category 
        self.business_type = business_type 
        self.consumption_type = consumption_type 
        self.created_at = created_at 
        self.remark = remark

    def get_broker_id(self):
        """ Get 综合服务主体 ID

        :return: string, broker_id
        """
        return self.broker_id

    def set_broker_id(self, broker_id):
        """ Set 综合服务主体 ID

        :type broker_id: string
        :param broker_id: 综合服务主体 ID
        """
        self.broker_id = broker_id

    def get_dealer_id(self):
        """ Get 平台企业 ID

        :return: string, dealer_id
        """
        return self.dealer_id

    def set_dealer_id(self, dealer_id):
        """ Set 平台企业 ID

        :type dealer_id: string
        :param dealer_id: 平台企业 ID
        """
        self.dealer_id = dealer_id

    def get_order_id(self):
        """ Get 平台企业订单号

        :return: string, order_id
        """
        return self.order_id

    def set_order_id(self, order_id):
        """ Set 平台企业订单号

        :type order_id: string
        :param order_id: 平台企业订单号
        """
        self.order_id = order_id

    def get_ref(self):
        """ Get 资金流水号

        :return: string, ref
        """
        return self.ref

    def set_ref(self, ref):
        """ Set 资金流水号

        :type ref: string
        :param ref: 资金流水号
        """
        self.ref = ref

    def get_broker_product_name(self):
        """ Get 综合服务主体名称

        :return: string, broker_product_name
        """
        return self.broker_product_name

    def set_broker_product_name(self, broker_product_name):
        """ Set 综合服务主体名称

        :type broker_product_name: string
        :param broker_product_name: 综合服务主体名称
        """
        self.broker_product_name = broker_product_name

    def get_dealer_product_name(self):
        """ Get 平台企业名称

        :return: string, dealer_product_name
        """
        return self.dealer_product_name

    def set_dealer_product_name(self, dealer_product_name):
        """ Set 平台企业名称

        :type dealer_product_name: string
        :param dealer_product_name: 平台企业名称
        """
        self.dealer_product_name = dealer_product_name

    def get_biz_ref(self):
        """ Get 业务订单流水号

        :return: string, biz_ref
        """
        return self.biz_ref

    def set_biz_ref(self, biz_ref):
        """ Set 业务订单流水号

        :type biz_ref: string
        :param biz_ref: 业务订单流水号
        """
        self.biz_ref = biz_ref

    def get_acct_type(self):
        """ Get 账户类型

        :return: string, acct_type
        """
        return self.acct_type

    def set_acct_type(self, acct_type):
        """ Set 账户类型

        :type acct_type: string
        :param acct_type: 账户类型
        """
        self.acct_type = acct_type

    def get_amount(self):
        """ Get 入账金额

        :return: string, amount
        """
        return self.amount

    def set_amount(self, amount):
        """ Set 入账金额

        :type amount: string
        :param amount: 入账金额
        """
        self.amount = amount

    def get_balance(self):
        """ Get 账户余额

        :return: string, balance
        """
        return self.balance

    def set_balance(self, balance):
        """ Set 账户余额

        :type balance: string
        :param balance: 账户余额
        """
        self.balance = balance

    def get_business_category(self):
        """ Get 业务分类

        :return: string, business_category
        """
        return self.business_category

    def set_business_category(self, business_category):
        """ Set 业务分类

        :type business_category: string
        :param business_category: 业务分类
        """
        self.business_category = business_category

    def get_business_type(self):
        """ Get 业务类型

        :return: string, business_type
        """
        return self.business_type

    def set_business_type(self, business_type):
        """ Set 业务类型

        :type business_type: string
        :param business_type: 业务类型
        """
        self.business_type = business_type

    def get_consumption_type(self):
        """ Get 收支类型

        :return: string, consumption_type
        """
        return self.consumption_type

    def set_consumption_type(self, consumption_type):
        """ Set 收支类型

        :type consumption_type: string
        :param consumption_type: 收支类型
        """
        self.consumption_type = consumption_type

    def get_created_at(self):
        """ Get 入账时间

        :return: string, created_at
        """
        return self.created_at

    def set_created_at(self, created_at):
        """ Set 入账时间

        :type created_at: string
        :param created_at: 入账时间
        """
        self.created_at = created_at

    def get_remark(self):
        """ Get 备注

        :return: string, remark
        """
        return self.remark

    def set_remark(self, remark):
        """ Set 备注

        :type remark: string
        :param remark: 备注
        """
        self.remark = remark 

class GetDailyOrderFileV2Request(BaseRequest):
    """
    
    :type order_date: string
    :param order_date: 订单查询日期, 格式：yyyy-MM-dd
    """
    def __init__(self, order_date=None):
        super().__init__() 
        self.order_date = order_date

    def get_order_date(self):
        """ Get 订单查询日期, 格式：yyyy-MM-dd

        :return: string, order_date
        """
        return self.order_date

    def set_order_date(self, order_date):
        """ Set 订单查询日期, 格式：yyyy-MM-dd

        :type order_date: string
        :param order_date: 订单查询日期, 格式：yyyy-MM-dd
        """
        self.order_date = order_date 

class GetDailyOrderFileV2Response(BaseRequest):
    """
    
    :type url: string
    :param url: 下载地址
    """
    def __init__(self, url=None):
        super().__init__() 
        self.url = url

    def get_url(self):
        """ Get 下载地址

        :return: string, url
        """
        return self.url

    def set_url(self, url):
        """ Set 下载地址

        :type url: string
        :param url: 下载地址
        """
        self.url = url 

class ListBalanceDailyStatementRequest(BaseRequest):
    """
    
    :type statement_date: string
    :param statement_date: 账单查询日期 格式：yyyy-MM-dd
    """
    def __init__(self, statement_date=None):
        super().__init__() 
        self.statement_date = statement_date

    def get_statement_date(self):
        """ Get 账单查询日期 格式：yyyy-MM-dd

        :return: string, statement_date
        """
        return self.statement_date

    def set_statement_date(self, statement_date):
        """ Set 账单查询日期 格式：yyyy-MM-dd

        :type statement_date: string
        :param statement_date: 账单查询日期 格式：yyyy-MM-dd
        """
        self.statement_date = statement_date 

class ListBalanceDailyStatementResponse(BaseRequest):
    """
    
    :type list: list
    :param list: 条目信息
    """
    def __init__(self, list=None):
        super().__init__() 
        self.list = list

    def get_list(self):
        """ Get 条目信息

        :return: list, list
        """
        return self.list

    def set_list(self, list):
        """ Set 条目信息

        :type list: list
        :param list: 条目信息
        """
        self.list = list 

class StatementDetail(BaseRequest):
    """
    
    :type statement_id: string
    :param statement_id: 账单 ID
    
    :type statement_date: string
    :param statement_date: 账单日期
    
    :type broker_id: string
    :param broker_id: 综合服务主体 ID
    
    :type dealer_id: string
    :param dealer_id: 平台企业 ID
    
    :type broker_product_name: string
    :param broker_product_name: 综合服务主体名称
    
    :type dealer_product_name: string
    :param dealer_product_name: 平台企业名称
    
    :type biz_type: string
    :param biz_type: 业务类型
    
    :type total_money: string
    :param total_money: 账单金额
    
    :type amount: string
    :param amount: 订单金额
    
    :type reex_amount: string
    :param reex_amount: 退汇金额
    
    :type fee_amount: string
    :param fee_amount: 加成服务费金额
    
    :type deduct_rebate_fee_amount: string
    :param deduct_rebate_fee_amount: 加成服务费抵扣金额
    
    :type money_adjust: string
    :param money_adjust: 冲补金额
    
    :type status: string
    :param status: 账单状态
    
    :type invoice_status: string
    :param invoice_status: 开票状态
    
    :type project_id: string
    :param project_id: 项目 ID
    
    :type project_name: string
    :param project_name: 项目名称
    """
    def __init__(self, statement_id=None, statement_date=None, broker_id=None, dealer_id=None, broker_product_name=None, dealer_product_name=None, biz_type=None, total_money=None, amount=None, reex_amount=None, fee_amount=None, deduct_rebate_fee_amount=None, money_adjust=None, status=None, invoice_status=None, project_id=None, project_name=None):
        super().__init__() 
        self.statement_id = statement_id 
        self.statement_date = statement_date 
        self.broker_id = broker_id 
        self.dealer_id = dealer_id 
        self.broker_product_name = broker_product_name 
        self.dealer_product_name = dealer_product_name 
        self.biz_type = biz_type 
        self.total_money = total_money 
        self.amount = amount 
        self.reex_amount = reex_amount 
        self.fee_amount = fee_amount 
        self.deduct_rebate_fee_amount = deduct_rebate_fee_amount 
        self.money_adjust = money_adjust 
        self.status = status 
        self.invoice_status = invoice_status 
        self.project_id = project_id 
        self.project_name = project_name

    def get_statement_id(self):
        """ Get 账单 ID

        :return: string, statement_id
        """
        return self.statement_id

    def set_statement_id(self, statement_id):
        """ Set 账单 ID

        :type statement_id: string
        :param statement_id: 账单 ID
        """
        self.statement_id = statement_id

    def get_statement_date(self):
        """ Get 账单日期

        :return: string, statement_date
        """
        return self.statement_date

    def set_statement_date(self, statement_date):
        """ Set 账单日期

        :type statement_date: string
        :param statement_date: 账单日期
        """
        self.statement_date = statement_date

    def get_broker_id(self):
        """ Get 综合服务主体 ID

        :return: string, broker_id
        """
        return self.broker_id

    def set_broker_id(self, broker_id):
        """ Set 综合服务主体 ID

        :type broker_id: string
        :param broker_id: 综合服务主体 ID
        """
        self.broker_id = broker_id

    def get_dealer_id(self):
        """ Get 平台企业 ID

        :return: string, dealer_id
        """
        return self.dealer_id

    def set_dealer_id(self, dealer_id):
        """ Set 平台企业 ID

        :type dealer_id: string
        :param dealer_id: 平台企业 ID
        """
        self.dealer_id = dealer_id

    def get_broker_product_name(self):
        """ Get 综合服务主体名称

        :return: string, broker_product_name
        """
        return self.broker_product_name

    def set_broker_product_name(self, broker_product_name):
        """ Set 综合服务主体名称

        :type broker_product_name: string
        :param broker_product_name: 综合服务主体名称
        """
        self.broker_product_name = broker_product_name

    def get_dealer_product_name(self):
        """ Get 平台企业名称

        :return: string, dealer_product_name
        """
        return self.dealer_product_name

    def set_dealer_product_name(self, dealer_product_name):
        """ Set 平台企业名称

        :type dealer_product_name: string
        :param dealer_product_name: 平台企业名称
        """
        self.dealer_product_name = dealer_product_name

    def get_biz_type(self):
        """ Get 业务类型

        :return: string, biz_type
        """
        return self.biz_type

    def set_biz_type(self, biz_type):
        """ Set 业务类型

        :type biz_type: string
        :param biz_type: 业务类型
        """
        self.biz_type = biz_type

    def get_total_money(self):
        """ Get 账单金额

        :return: string, total_money
        """
        return self.total_money

    def set_total_money(self, total_money):
        """ Set 账单金额

        :type total_money: string
        :param total_money: 账单金额
        """
        self.total_money = total_money

    def get_amount(self):
        """ Get 订单金额

        :return: string, amount
        """
        return self.amount

    def set_amount(self, amount):
        """ Set 订单金额

        :type amount: string
        :param amount: 订单金额
        """
        self.amount = amount

    def get_reex_amount(self):
        """ Get 退汇金额

        :return: string, reex_amount
        """
        return self.reex_amount

    def set_reex_amount(self, reex_amount):
        """ Set 退汇金额

        :type reex_amount: string
        :param reex_amount: 退汇金额
        """
        self.reex_amount = reex_amount

    def get_fee_amount(self):
        """ Get 加成服务费金额

        :return: string, fee_amount
        """
        return self.fee_amount

    def set_fee_amount(self, fee_amount):
        """ Set 加成服务费金额

        :type fee_amount: string
        :param fee_amount: 加成服务费金额
        """
        self.fee_amount = fee_amount

    def get_deduct_rebate_fee_amount(self):
        """ Get 加成服务费抵扣金额

        :return: string, deduct_rebate_fee_amount
        """
        return self.deduct_rebate_fee_amount

    def set_deduct_rebate_fee_amount(self, deduct_rebate_fee_amount):
        """ Set 加成服务费抵扣金额

        :type deduct_rebate_fee_amount: string
        :param deduct_rebate_fee_amount: 加成服务费抵扣金额
        """
        self.deduct_rebate_fee_amount = deduct_rebate_fee_amount

    def get_money_adjust(self):
        """ Get 冲补金额

        :return: string, money_adjust
        """
        return self.money_adjust

    def set_money_adjust(self, money_adjust):
        """ Set 冲补金额

        :type money_adjust: string
        :param money_adjust: 冲补金额
        """
        self.money_adjust = money_adjust

    def get_status(self):
        """ Get 账单状态

        :return: string, status
        """
        return self.status

    def set_status(self, status):
        """ Set 账单状态

        :type status: string
        :param status: 账单状态
        """
        self.status = status

    def get_invoice_status(self):
        """ Get 开票状态

        :return: string, invoice_status
        """
        return self.invoice_status

    def set_invoice_status(self, invoice_status):
        """ Set 开票状态

        :type invoice_status: string
        :param invoice_status: 开票状态
        """
        self.invoice_status = invoice_status

    def get_project_id(self):
        """ Get 项目 ID

        :return: string, project_id
        """
        return self.project_id

    def set_project_id(self, project_id):
        """ Set 项目 ID

        :type project_id: string
        :param project_id: 项目 ID
        """
        self.project_id = project_id

    def get_project_name(self):
        """ Get 项目名称

        :return: string, project_name
        """
        return self.project_name

    def set_project_name(self, project_name):
        """ Set 项目名称

        :type project_name: string
        :param project_name: 项目名称
        """
        self.project_name = project_name


from ...base import BaseRequest
 

class GetTaxFileRequest(BaseRequest):
    """
    
    :type dealer_id: string
    :param dealer_id: 平台企业 ID
    
    :type ent_id: string
    :param ent_id: 平台企业签约主体
    
    :type year_month: string
    :param year_month: 所属期
    """
    def __init__(self, dealer_id=None, ent_id=None, year_month=None):
        super().__init__() 
        self.dealer_id = dealer_id 
        self.ent_id = ent_id 
        self.year_month = year_month

    def get_dealer_id(self):
        """ Get 平台企业 ID

        :return: string, dealer_id
        """
        return self.dealer_id

    def set_dealer_id(self, dealer_id):
        """ Set 平台企业 ID

        :type dealer_id: string
        :param dealer_id: 平台企业 ID
        """
        self.dealer_id = dealer_id

    def get_ent_id(self):
        """ Get 平台企业签约主体

        :return: string, ent_id
        """
        return self.ent_id

    def set_ent_id(self, ent_id):
        """ Set 平台企业签约主体

        :type ent_id: string
        :param ent_id: 平台企业签约主体
        """
        self.ent_id = ent_id

    def get_year_month(self):
        """ Get 所属期

        :return: string, year_month
        """
        return self.year_month

    def set_year_month(self, year_month):
        """ Set 所属期

        :type year_month: string
        :param year_month: 所属期
        """
        self.year_month = year_month 

class GetTaxFileResponse(BaseRequest):
    """
    
    :type file_info: list
    :param file_info: 文件详情
    """
    def __init__(self, file_info=None):
        super().__init__() 
        self.file_info = file_info

    def get_file_info(self):
        """ Get 文件详情

        :return: list, file_info
        """
        return self.file_info

    def set_file_info(self, file_info):
        """ Set 文件详情

        :type file_info: list
        :param file_info: 文件详情
        """
        self.file_info = file_info 

class FileInfo(BaseRequest):
    """
    
    :type name: string
    :param name: 文件名称
    
    :type url: string
    :param url: 下载文件临时 URL
    
    :type pwd: string
    :param pwd: 文件解压缩密码
    """
    def __init__(self, name=None, url=None, pwd=None):
        super().__init__() 
        self.name = name 
        self.url = url 
        self.pwd = pwd

    def get_name(self):
        """ Get 文件名称

        :return: string, name
        """
        return self.name

    def set_name(self, name):
        """ Set 文件名称

        :type name: string
        :param name: 文件名称
        """
        self.name = name

    def get_url(self):
        """ Get 下载文件临时 URL

        :return: string, url
        """
        return self.url

    def set_url(self, url):
        """ Set 下载文件临时 URL

        :type url: string
        :param url: 下载文件临时 URL
        """
        self.url = url

    def get_pwd(self):
        """ Get 文件解压缩密码

        :return: string, pwd
        """
        return self.pwd

    def set_pwd(self, pwd):
        """ Set 文件解压缩密码

        :type pwd: string
        :param pwd: 文件解压缩密码
        """
        self.pwd = pwd 

class GetUserCrossRequest(BaseRequest):
    """
    
    :type dealer_id: string
    :param dealer_id: 平台企业 ID
    
    :type year: string
    :param year: 年份
    
    :type id_card: string
    :param id_card: 身份证号码
    
    :type ent_id: string
    :param ent_id: 平台企业签约主体
    """
    def __init__(self, dealer_id=None, year=None, id_card=None, ent_id=None):
        super().__init__() 
        self.dealer_id = dealer_id 
        self.year = year 
        self.id_card = id_card 
        self.ent_id = ent_id

    def get_dealer_id(self):
        """ Get 平台企业 ID

        :return: string, dealer_id
        """
        return self.dealer_id

    def set_dealer_id(self, dealer_id):
        """ Set 平台企业 ID

        :type dealer_id: string
        :param dealer_id: 平台企业 ID
        """
        self.dealer_id = dealer_id

    def get_year(self):
        """ Get 年份

        :return: string, year
        """
        return self.year

    def set_year(self, year):
        """ Set 年份

        :type year: string
        :param year: 年份
        """
        self.year = year

    def get_id_card(self):
        """ Get 身份证号码

        :return: string, id_card
        """
        return self.id_card

    def set_id_card(self, id_card):
        """ Set 身份证号码

        :type id_card: string
        :param id_card: 身份证号码
        """
        self.id_card = id_card

    def get_ent_id(self):
        """ Get 平台企业签约主体

        :return: string, ent_id
        """
        return self.ent_id

    def set_ent_id(self, ent_id):
        """ Set 平台企业签约主体

        :type ent_id: string
        :param ent_id: 平台企业签约主体
        """
        self.ent_id = ent_id 

class GetUserCrossResponse(BaseRequest):
    """
    
    :type is_cross: bool
    :param is_cross: 跨集团标识
    """
    def __init__(self, is_cross=None):
        super().__init__() 
        self.is_cross = is_cross

    def get_is_cross(self):
        """ Get 跨集团标识

        :return: bool, is_cross
        """
        return self.is_cross

    def set_is_cross(self, is_cross):
        """ Set 跨集团标识

        :type is_cross: bool
        :param is_cross: 跨集团标识
        """
        self.is_cross = is_cross